Winston 支持以下 7 个日志等级（按优先级从高到低排序）：

## 📊 Winston 日志级别

| 级别        | 优先级 | 描述   | 使用场景             |
| ----------- | ------ | ------ | -------------------- |
| **error**   | 0      | 错误   | 系统错误、异常、崩溃 |
| **warn**    | 1      | 警告   | 潜在问题、性能警告   |
| **info**    | 2      | 信息   | 一般信息、重要事件   |
| **http**    | 3      | HTTP   | HTTP 请求/响应日志   |
| **verbose** | 4      | 详细   | 详细操作信息         |
| **debug**   | 5      | 调试   | 调试信息、开发阶段   |
| **silly**   | 6      | 最详细 | 极其详细的调试信息   |

## 🎯 级别过滤机制

当你设置日志级别时，Winston 会记录**该级别及更高优先级**的所有日志：

```typescript
// 如果设置 level: 'warn'
logger.level = 'warn';

logger.error('会被记录'); // ✅ 优先级 0
logger.warn('会被记录'); // ✅ 优先级 1
logger.info('不会被记录'); // ❌ 优先级 2
logger.debug('不会被记录'); // ❌ 优先级 5
```

## 💡 在你的日志器中使用

你可以更新日志器类来支持所有级别：

```typescript
export class Logger {
    static error(message: string): void {
        logger.error(message);
    }

    static warn(message: string): void {
        logger.warn(message);
    }

    static info(message: string): void {
        logger.info(message);
    }

    static http(message: string): void {
        logger.http(message);
    }

    static verbose(message: string): void {
        logger.verbose(message);
    }

    static debug(message: string): void {
        logger.debug(message);
    }

    static silly(message: string): void {
        logger.silly(message);
    }
}
```

## 🔧 常用配置

```typescript
// 生产环境：只记录重要信息
level: 'warn'; // 记录 error, warn

// 开发环境：记录详细信息
level: 'debug'; // 记录 error, warn, info, http, verbose, debug

// 调试模式：记录所有信息
level: 'silly'; // 记录所有级别
```

这样你就可以根据不同环境灵活控制日志的详细程度了！
