/**
 * @file        Drizzle配置文件
 * @author      hotok
 * @date        2025-06-29
 * @lastEditor  hotok
 * @lastEditTime 2025-06-29
 * @description Drizzle Kit配置，用于数据库迁移和代码生成
 */

import { dbConfig } from '@/config';

/** 
 * Drizzle Kit配置对象
 * 使用前需要安装: bun add drizzle-kit -D
 */
export default {
    /** 数据库类型 */
    dialect: 'mysql',
    
    /** 数据库连接配置 */
    dbCredentials: {
        host: dbConfig.host,
        port: dbConfig.port,
        user: dbConfig.user,
        password: dbConfig.password,
        database: dbConfig.database,
    },
    
    /** Schema文件路径 */
    schema: './src/entities/schema.js',
    
    /** 迁移文件输出目录 */
    out: './drizzle',
    
    /** 详细日志 */
    verbose: true,
    
    /** 严格模式 */
    strict: true,
    
    introspect: {
        // 启用驼峰命名
        casing: 'camel',
    },
} as const;