/**
 * @file        Plugins 插件总入口
 * @author      hotok
 * @date        2025-06-29
 * @lastEditor  hotok
 * @lastEditTime 2025-06-29
 * @description 所有插件的统一入口，使用 group 进行模块化管理
 */

import { Elysia } from 'elysia';
import { loggerPlugin } from '@/plugins/logger/logger.plugins';
import { errorHandlerPlugin } from '@/plugins/errorHandle/errorHandler.plugins';
import { swaggerPlugin } from '@/plugins/swagger/swagger.plugins';
import { drizzlePlugin } from '@/plugins/drizzle/drizzle.plugins';
import { redisPlugin } from '@/plugins/redis/redis.plugins';
import { emailPlugin } from '@/plugins/email/email.plugins';

export const plugins = (app: Elysia) =>
    app
        // 日志插件
        .use(loggerPlugin)
        // 错误处理插件
        .use(errorHandlerPlugin)
        // 数据库插件
        .use(drizzlePlugin)
        // Redis插件
        .use(redisPlugin)
        // 邮件服务插件
        .use(emailPlugin)
        // API 文档插件
        .use(swaggerPlugin);
