/**
 * @file        Redis类型定义
 * @author      hotok
 * @date        2025-06-29
 * @lastEditor  hotok
 * @lastEditTime 2025-06-29
 * @description 定义Redis相关的类型，包括连接状态、配置信息等
 */

import type { RedisClientType } from 'redis';

/**
 * Redis客户端类型
 */
export type RedisClient = RedisClientType;

/**
 * Redis连接状态
 */
export type RedisConnectionStatus = 'connecting' | 'connected' | 'error' | 'disconnected';

/**
 * Redis连接信息
 */
export interface RedisConnectionInfo {
    /** 连接状态 */
    status: RedisConnectionStatus;
    /** 连接主机 */
    host: string;
    /** 连接端口 */
    port: number;
    /** 数据库索引 */
    database: number;
    /** 连接名称 */
    connectName: string;
    /** 连接时间 */
    connectedAt?: Date;
    /** 错误信息 */
    error?: string;
    /** 是否已连接 */
    isConnected: boolean;
}

/**
 * 扩展Elysia Context，添加Redis实例
 */
export interface RedisContext {
    /** Redis客户端实例 */
    redis: RedisClient;
}

/**
 * Redis健康检查结果
 */
export interface RedisHealthCheckResult {
    /** 状态 */
    status: 'healthy' | 'unhealthy';
    /** 响应时间 */
    responseTime: number;
    /** 连接信息 */
    connectionInfo: RedisConnectionInfo;
    /** 错误信息 */
    error?: string;
} 