import { UAParser } from 'ua-parser-js';

/**
 * 解析 UserAgent 获取设备信息
 * @param userAgent UserAgent 字符串
 * @returns 设备信息对象
 */
export const parseUserAgent = (userAgent: string | null) => {
    if (!userAgent) return null;

    const parser = new UAParser(userAgent);
    const result = parser.getResult();

    return {
        browser: `${result.browser.name || 'Unknown'} ${result.browser.version || ''}`.trim(),
        os: `${result.os.name || 'Unknown'} ${result.os.version || ''}`.trim(),
        device: {
            type: result.device.type || 'desktop', // mobile, tablet, desktop
            vendor: result.device.vendor || 'Unknown',
            model: result.device.model || 'Unknown',
        },
        engine: result.engine.name || 'Unknown',
        isBot: /bot|crawler|spider|crawling/i.test(userAgent),
    };
};

export const browserInfo = (userAgent: string | null) => {
    if (!userAgent) return null;

    const parser = new UAParser(userAgent);
    const result = parser.getResult();

    return `${result.browser.name || 'Unknown'} ${result.browser.version || ''}`.trim();
};
