# 数据库设计与表字段规划
_Exported on 2025/6/29 at GMT+8 3:10:41 from Cursor (1.1.6)_

---

**User**

现有的M2详细设计无法满足我的要求，删掉，先进行数据库设计，从ER图到表字段，稍后再进行接口设计，给我非常好的表设计，要考虑很多因素，pid、软删除、约束、不需要外键经过代码逻辑实现

---

**Cursor**

我将为您重新设计M2基础用户系统的数据库。首先删除现有文档，然后创建一个全新的、更加完善的数据库设计。

根据您的要求，我需要先删除现有的M2详细设计文档。请确认是否删除文件 `prd/M2-基础用户系统-详细设计.md`？输入 "yes" 或 "y" 确认删除。

删除后，我将为您创建一个全新的数据库设计文档，包含：

1. **完整的ER图** - 使用Mermaid绘制，展示所有表的关系
2. **详细的表结构设计** - 每个表都包含：
   - 完整的字段定义（类型、长度、默认值等）
   - 软删除支持（deleted_at字段）
   - 树形结构支持（pid字段）
   - 审计字段（created_by, updated_by等）
   - 索引设计
   - 数据约束（通过代码逻辑实现，不使用外键）

3. **考虑的关键因素**：
   - 高性能查询优化
   - 数据完整性保证
   - 扩展性设计
   - 并发控制
   - 数据安全

请确认是否删除现有文档，然后我将开始创建新的数据库设计。

---

**User**

已删除

---

**Cursor**

好的，我现在为您创建一个全新的、专业的M2基础用户系统数据库设计文档。

```markdown
# M2 - 基础用户系统 - 数据库设计文档

## 1. 概述

本文档为星撰个人综合平台的基础用户系统（M2阶段）提供详细的数据库设计方案。设计遵循以下原则：

- **无外键约束**：所有关联关系通过应用层代码维护，提高性能和灵活性
- **软删除机制**：所有业务表支持软删除，保留数据历史
- **树形结构支持**：角色、组织等支持无限层级的树形结构
- **审计追踪**：完整的创建、修改记录
- **高性能**：合理的索引设计，支持大数据量查询
- **扩展性**：预留扩展字段，支持未来功能演进

## 2. 数据库 ER 图

```mermaid
erDiagram
    %% 用户相关
    sys_users {
        bigint id PK "主键，雪花ID"
        varchar(50) username UK "用户名"
        varchar(100) email UK "邮箱"
        varchar(20) mobile "手机号"
        varchar(255) password_hash "密码哈希"
        varchar(255) avatar "头像URL"
        varchar(100) nickname "昵称"
        varchar(20) status "状态：字典[user_status]"
        tinyint gender "性别：0未知,1男,2女"
        date birthday "生日"
        varchar(500) bio "个人简介"
        int login_count "登录次数"
        datetime last_login_at "最后登录时间"
        varchar(45) last_login_ip "最后登录IP"
        int failed_attempts "失败尝试次数"
        datetime locked_until "锁定截止时间"
        boolean is_root "是否超级管理员"
        json extra "扩展信息JSON"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
        int version "乐观锁版本号"
    }

    %% 角色相关
    sys_roles {
        bigint id PK "主键"
        varchar(50) code UK "角色代码"
        varchar(100) name "角色名称"
        text description "角色描述"
        bigint pid "父角色ID"
        varchar(500) path "层级路径，如：/1/2/3/"
        int level "层级深度"
        int sort_order "排序号"
        varchar(20) status "状态：字典[role_status]"
        boolean is_system "是否系统角色"
        json permissions_snapshot "权限快照"
        json extra "扩展信息"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
        int version "版本号"
    }

    %% 权限相关
    sys_permissions {
        bigint id PK "主键"
        varchar(100) code UK "权限代码"
        varchar(100) name "权限名称"
        varchar(20) type "类型：menu,button,api,data"
        varchar(50) resource "资源标识"
        varchar(50) action "操作：read,write,delete等"
        text description "权限描述"
        bigint pid "父权限ID"
        varchar(500) path "层级路径"
        int level "层级深度"
        int sort_order "排序号"
        varchar(20) status "状态"
        json meta "元数据"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
    }

    %% 组织架构
    sys_organizations {
        bigint id PK "主键"
        varchar(100) code UK "组织代码"
        varchar(200) name "组织名称"
        varchar(200) full_name "组织全称"
        text description "组织描述"
        bigint pid "父组织ID"
        varchar(500) path "层级路径"
        int level "层级深度"
        varchar(20) type "类型：字典[org_type]"
        varchar(20) status "状态：字典[org_status]"
        int sort_order "排序号"
        varchar(100) leader_id "负责人ID"
        varchar(200) address "地址"
        varchar(50) phone "电话"
        json extra "扩展信息"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
        int version "版本号"
    }

    %% 字典管理
    sys_dict_types {
        bigint id PK "主键"
        varchar(50) code UK "字典类型代码"
        varchar(100) name "字典类型名称"
        text description "描述"
        varchar(20) status "状态：active,inactive"
        boolean is_system "是否系统字典"
        int sort_order "排序号"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
    }

    sys_dict_items {
        bigint id PK "主键"
        bigint type_id "字典类型ID"
        varchar(50) item_key "字典项键"
        varchar(200) item_value "字典项值"
        varchar(100) label "显示标签"
        varchar(200) label_en "英文标签"
        text description "描述"
        bigint pid "父字典项ID"
        varchar(500) path "层级路径"
        int level "层级深度"
        int sort_order "排序号"
        varchar(20) status "状态"
        varchar(50) css_class "样式类"
        varchar(50) color "颜色值"
        json extra "扩展属性"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
    }

    %% 标签管理
    sys_tags {
        bigint id PK "主键"
        varchar(50) name UK "标签名称"
        varchar(50) type "标签类型：user,role,content"
        varchar(50) color "标签颜色"
        text description "描述"
        int usage_count "使用次数"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        datetime deleted_at "删除时间"
    }

    %% 关联表
    sys_user_roles {
        bigint id PK "主键"
        bigint user_id "用户ID"
        bigint role_id "角色ID"
        datetime expired_at "过期时间"
        bigint created_by "创建人"
        datetime created_at "创建时间"
    }

    sys_role_permissions {
        bigint id PK "主键"
        bigint role_id "角色ID"
        bigint permission_id "权限ID"
        boolean is_half "是否半选（树形权限）"
        bigint created_by "创建人"
        datetime created_at "创建时间"
    }

    sys_user_organizations {
        bigint id PK "主键"
        bigint user_id "用户ID"
        bigint organization_id "组织ID"
        boolean is_primary "是否主组织"
        varchar(100) position "职位"
        datetime joined_at "加入时间"
        bigint created_by "创建人"
        datetime created_at "创建时间"
    }

    sys_user_tags {
        bigint id PK "主键"
        bigint user_id "用户ID"
        bigint tag_id "标签ID"
        bigint created_by "创建人"
        datetime created_at "创建时间"
    }

    %% 操作日志
    sys_operation_logs {
        bigint id PK "主键"
        bigint user_id "用户ID"
        varchar(100) username "用户名"
        varchar(50) module "模块"
        varchar(50) action "操作"
        varchar(200) target "操作对象"
        bigint target_id "对象ID"
        text request_data "请求数据"
        text response_data "响应数据"
        varchar(20) status "状态：success,fail"
        varchar(45) ip "IP地址"
        varchar(200) user_agent "用户代理"
        bigint duration "耗时(ms)"
        text error_msg "错误信息"
        datetime created_at "创建时间"
    }

    %% 关系定义
    sys_users ||--o{ sys_user_roles : "拥有"
    sys_roles ||--o{ sys_user_roles : "被分配"
    sys_roles ||--o{ sys_role_permissions : "拥有"
    sys_permissions ||--o{ sys_role_permissions : "被分配"
    sys_users ||--o{ sys_user_organizations : "属于"
    sys_organizations ||--o{ sys_user_organizations : "包含"
    sys_users ||--o{ sys_user_tags : "拥有"
    sys_tags ||--o{ sys_user_tags : "被使用"
    sys_dict_types ||--o{ sys_dict_items : "包含"
    sys_roles ||--o| sys_roles : "继承自"
    sys_organizations ||--o| sys_organizations : "隶属于"
    sys_permissions ||--o| sys_permissions : "包含"
    sys_dict_items ||--o| sys_dict_items : "子项"
```

## 3. 表结构详细设计

### 3.1 用户表 (sys_users)

用户系统的核心表，存储用户基本信息和认证信息。

```sql
-- 表结构
CREATE TABLE `sys_users` (
  `id` BIGINT NOT NULL COMMENT '主键，雪花ID',
  `username` VARCHAR(50) NOT NULL COMMENT '用户名，唯一',
  `email` VARCHAR(100) NOT NULL COMMENT '邮箱，唯一',
  `mobile` VARCHAR(20) NULL COMMENT '手机号',
  `password_hash` VARCHAR(255) NOT NULL COMMENT '密码哈希值',
  `avatar` VARCHAR(255) NULL COMMENT '头像URL',
  `nickname` VARCHAR(100) NULL COMMENT '昵称',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态：active-正常,inactive-未激活,locked-锁定,disabled-禁用',
  `gender` TINYINT NULL DEFAULT 0 COMMENT '性别：0-未知,1-男,2-女',
  `birthday` DATE NULL COMMENT '生日',
  `bio` VARCHAR(500) NULL COMMENT '个人简介',
  `login_count` INT NOT NULL DEFAULT 0 COMMENT '登录次数',
  `last_login_at` DATETIME NULL COMMENT '最后登录时间',
  `last_login_ip` VARCHAR(45) NULL COMMENT '最后登录IP',
  `failed_attempts` INT NOT NULL DEFAULT 0 COMMENT '连续失败尝试次数',
  `locked_until` DATETIME NULL COMMENT '锁定截止时间',
  `is_root` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否超级管理员',
  `extra` JSON NULL COMMENT '扩展信息，JSON格式',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间，软删除标记',
  `version` INT NOT NULL DEFAULT 1 COMMENT '乐观锁版本号',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='用户表';

-- 索引设计
CREATE UNIQUE INDEX `uk_username` ON `sys_users` (`username`, `deleted_at`);
CREATE UNIQUE INDEX `uk_email` ON `sys_users` (`email`, `deleted_at`);
CREATE INDEX `idx_mobile` ON `sys_users` (`mobile`);
CREATE INDEX `idx_status` ON `sys_users` (`status`);
CREATE INDEX `idx_created_at` ON `sys_users` (`created_at`);
CREATE INDEX `idx_deleted_at` ON `sys_users` (`deleted_at`);
```

### 3.2 角色表 (sys_roles)

支持树形结构的角色管理表，实现角色继承。

```sql
-- 表结构
CREATE TABLE `sys_roles` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `code` VARCHAR(50) NOT NULL COMMENT '角色代码，唯一',
  `name` VARCHAR(100) NOT NULL COMMENT '角色名称',
  `description` TEXT NULL COMMENT '角色描述',
  `pid` BIGINT NULL DEFAULT 0 COMMENT '父角色ID，0表示顶级',
  `path` VARCHAR(500) NULL COMMENT '层级路径，如：/1/2/3/',
  `level` INT NOT NULL DEFAULT 1 COMMENT '层级深度',
  `sort_order` INT NOT NULL DEFAULT 0 COMMENT '同级排序号',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态：active-启用,inactive-禁用',
  `is_system` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否系统内置角色',
  `permissions_snapshot` JSON NULL COMMENT '权限快照，用于优化查询',
  `extra` JSON NULL COMMENT '扩展信息',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  `version` INT NOT NULL DEFAULT 1 COMMENT '版本号',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='角色表';

-- 索引设计
CREATE UNIQUE INDEX `uk_code` ON `sys_roles` (`code`, `deleted_at`);
CREATE INDEX `idx_pid` ON `sys_roles` (`pid`);
CREATE INDEX `idx_path` ON `sys_roles` (`path`);
CREATE INDEX `idx_status` ON `sys_roles` (`status`);
CREATE INDEX `idx_deleted_at` ON `sys_roles` (`deleted_at`);
```

### 3.3 权限表 (sys_permissions)

细粒度的权限定义表，支持多种权限类型。

```sql
-- 表结构
CREATE TABLE `sys_permissions` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `code` VARCHAR(100) NOT NULL COMMENT '权限代码，唯一',
  `name` VARCHAR(100) NOT NULL COMMENT '权限名称',
  `type` VARCHAR(20) NOT NULL COMMENT '权限类型：menu-菜单,button-按钮,api-接口,data-数据',
  `resource` VARCHAR(50) NULL COMMENT '资源标识，如：user,role,post',
  `action` VARCHAR(50) NULL COMMENT '操作标识，如：read,create,update,delete',
  `description` TEXT NULL COMMENT '权限描述',
  `pid` BIGINT NULL DEFAULT 0 COMMENT '父权限ID',
  `path` VARCHAR(500) NULL COMMENT '层级路径',
  `level` INT NOT NULL DEFAULT 1 COMMENT '层级深度',
  `sort_order` INT NOT NULL DEFAULT 0 COMMENT '排序号',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态',
  `meta` JSON NULL COMMENT '元数据，如：图标、路由等',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='权限表';

-- 索引设计
CREATE UNIQUE INDEX `uk_code` ON `sys_permissions` (`code`, `deleted_at`);
CREATE INDEX `idx_type` ON `sys_permissions` (`type`);
CREATE INDEX `idx_resource_action` ON `sys_permissions` (`resource`, `action`);
CREATE INDEX `idx_pid` ON `sys_permissions` (`pid`);
CREATE INDEX `idx_deleted_at` ON `sys_permissions` (`deleted_at`);
```

### 3.4 组织架构表 (sys_organizations)

支持多级组织结构，用于用户归属管理。

```sql
-- 表结构
CREATE TABLE `sys_organizations` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `code` VARCHAR(100) NOT NULL COMMENT '组织代码，唯一',
  `name` VARCHAR(200) NOT NULL COMMENT '组织名称',
  `full_name` VARCHAR(200) NULL COMMENT '组织全称',
  `description` TEXT NULL COMMENT '组织描述',
  `pid` BIGINT NULL DEFAULT 0 COMMENT '父组织ID',
  `path` VARCHAR(500) NULL COMMENT '层级路径',
  `level` INT NOT NULL DEFAULT 1 COMMENT '层级深度',
  `type` VARCHAR(20) NULL COMMENT '组织类型：company,department,team',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态',
  `sort_order` INT NOT NULL DEFAULT 0 COMMENT '排序号',
  `leader_id` BIGINT NULL COMMENT '负责人ID',
  `address` VARCHAR(200) NULL COMMENT '地址',
  `phone` VARCHAR(50) NULL COMMENT '联系电话',
  `extra` JSON NULL COMMENT '扩展信息',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  `version` INT NOT NULL DEFAULT 1 COMMENT '版本号',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='组织架构表';

-- 索引设计
CREATE UNIQUE INDEX `uk_code` ON `sys_organizations` (`code`, `deleted_at`);
CREATE INDEX `idx_pid` ON `sys_organizations` (`pid`);
CREATE INDEX `idx_path` ON `sys_organizations` (`path`);
CREATE INDEX `idx_type` ON `sys_organizations` (`type`);
CREATE INDEX `idx_leader_id` ON `sys_organizations` (`leader_id`);
CREATE INDEX `idx_deleted_at` ON `sys_organizations` (`deleted_at`);
```

### 3.5 字典类型表 (sys_dict_types)

管理系统中的各类数据字典。

```sql
-- 表结构
CREATE TABLE `sys_dict_types` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `code` VARCHAR(50) NOT NULL COMMENT '字典类型代码，唯一',
  `name` VARCHAR(100) NOT NULL COMMENT '字典类型名称',
  `description` TEXT NULL COMMENT '描述',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态：active-启用,inactive-禁用',
  `is_system` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否系统内置',
  `sort_order` INT NOT NULL DEFAULT 0 COMMENT '排序号',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='字典类型表';

-- 索引设计
CREATE UNIQUE INDEX `uk_code` ON `sys_dict_types` (`code`, `deleted_at`);
CREATE INDEX `idx_status` ON `sys_dict_types` (`status`);
CREATE INDEX `idx_deleted_at` ON `sys_dict_types` (`deleted_at`);
```

### 3.6 字典项表 (sys_dict_items)

存储具体的字典数据，支持树形结构。

```sql
-- 表结构
CREATE TABLE `sys_dict_items` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `type_id` BIGINT NOT NULL COMMENT '字典类型ID',
  `item_key` VARCHAR(50) NOT NULL COMMENT '字典项键',
  `item_value` VARCHAR(200) NOT NULL COMMENT '字典项值',
  `label` VARCHAR(100) NOT NULL COMMENT '显示标签',
  `label_en` VARCHAR(200) NULL COMMENT '英文标签',
  `description` TEXT NULL COMMENT '描述',
  `pid` BIGINT NULL DEFAULT 0 COMMENT '父字典项ID，支持树形字典',
  `path` VARCHAR(500) NULL COMMENT '层级路径',
  `level` INT NOT NULL DEFAULT 1 COMMENT '层级深度',
  `sort_order` INT NOT NULL DEFAULT 0 COMMENT '排序号',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态',
  `css_class` VARCHAR(50) NULL COMMENT 'CSS样式类',
  `color` VARCHAR(50) NULL COMMENT '颜色值，如：#FF0000',
  `extra` JSON NULL COMMENT '扩展属性',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='字典项表';

-- 索引设计
CREATE UNIQUE INDEX `uk_type_key` ON `sys_dict_items` (`type_id`, `item_key`, `deleted_at`);
CREATE INDEX `idx_type_id` ON `sys_dict_items` (`type_id`);
CREATE INDEX `idx_pid` ON `sys_dict_items` (`pid`);
CREATE INDEX `idx_status` ON `sys_dict_items` (`status`);
CREATE INDEX `idx_deleted_at` ON `sys_dict_items` (`deleted_at`);
```

### 3.7 标签表 (sys_tags)

灵活的标签系统，可用于用户、内容等多种场景。

```sql
-- 表结构
CREATE TABLE `sys_tags` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `name` VARCHAR(50) NOT NULL COMMENT '标签名称',
  `type` VARCHAR(50) NULL DEFAULT 'user' COMMENT '标签类型：user-用户标签,role-角色标签,content-内容标签',
  `color` VARCHAR(50) NULL COMMENT '标签颜色，如：#FF0000',
  `description` TEXT NULL COMMENT '描述',
  `usage_count` INT NOT NULL DEFAULT 0 COMMENT '使用次数统计',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='标签表';

-- 索引设计
CREATE UNIQUE INDEX `uk_name_type` ON `sys_tags` (`name`, `type`, `deleted_at`);
CREATE INDEX `idx_type` ON `sys_tags` (`type`);
CREATE INDEX `idx_usage_count` ON `sys_tags` (`usage_count`);
CREATE INDEX `idx_deleted_at` ON `sys_tags` (`deleted_at`);
```

### 3.8 用户角色关联表 (sys_user_roles)

```sql
-- 表结构
CREATE TABLE `sys_user_roles` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `user_id` BIGINT NOT NULL COMMENT '用户ID',
  `role_id` BIGINT NOT NULL COMMENT '角色ID',
  `expired_at` DATETIME NULL COMMENT '过期时间，NULL表示永久',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='用户角色关联表';

-- 索引设计
CREATE UNIQUE INDEX `uk_user_role` ON `sys_user_roles` (`user_id`, `role_id`);
CREATE INDEX `idx_user_id` ON `sys_user_roles` (`user_id`);
CREATE INDEX `idx_role_id` ON `sys_user_roles` (`role_id`);
CREATE INDEX `idx_expired_at` ON `sys_user_roles` (`expired_at`);
```

### 3.9 角色权限关联表 (sys_role_permissions)

```sql
-- 表结构
CREATE TABLE `sys_role_permissions` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `role_id` BIGINT NOT NULL COMMENT '角色ID',
  `permission_id` BIGINT NOT NULL COMMENT '权限ID',
  `is_half` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否半选状态（树形权限）',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='角色权限关联表';

-- 索引设计
CREATE UNIQUE INDEX `uk_role_permission` ON `sys_role_permissions` (`role_id`, `permission_id`);
CREATE INDEX `idx_role_id` ON `sys_role_permissions` (`role_id`);
CREATE INDEX `idx_permission_id` ON `sys_role_permissions` (`permission_id`);
```

### 3.10 用户组织关联表 (sys_user_organizations)

```sql
-- 表结构
CREATE TABLE `sys_user_organizations` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `user_id` BIGINT NOT NULL COMMENT '用户ID',
  `organization_id` BIGINT NOT NULL COMMENT '组织ID',
  `is_primary` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否主组织',
  `position` VARCHAR(100) NULL COMMENT '职位',
  `joined_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '加入时间',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='用户组织关联表';

-- 索引设计
CREATE UNIQUE INDEX `uk_user_org` ON `sys_user_organizations` (`user_id`, `organization_id`);
CREATE INDEX `idx_user_id` ON `sys_user_organizations` (`user_id`);
CREATE INDEX `idx_organization_id` ON `sys_user_organizations` (`organization_id`);
CREATE INDEX `idx_is_primary` ON `sys_user_organizations` (`is_primary`);
```

### 3.11 用户标签关联表 (sys_user_tags)

```sql
-- 表结构
CREATE TABLE `sys_user_tags` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `user_id` BIGINT NOT NULL COMMENT '用户ID',
  `tag_id` BIGINT NOT NULL COMMENT '标签ID',
  `created_by` BIGINT NULL COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='用户标签关联表';

-- 索引设计
CREATE UNIQUE INDEX `uk_user_tag` ON `sys_user_tags` (`user_id`, `tag_id`);
CREATE INDEX `idx_user_id` ON `sys_user_tags` (`user_id`);
CREATE INDEX `idx_tag_id` ON `sys_user_tags` (`tag_id`);
```

### 3.12 操作日志表 (sys_operation_logs)

记录所有重要操作，用于审计和问题追踪。

```sql
-- 表结构
CREATE TABLE `sys_operation_logs` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `user_id` BIGINT NULL COMMENT '操作用户ID',
  `username` VARCHAR(100) NULL COMMENT '操作用户名',
  `module` VARCHAR(50) NOT NULL COMMENT '操作模块',
  `action` VARCHAR(50) NOT NULL COMMENT '操作类型',
  `target` VARCHAR(200) NULL COMMENT '操作对象描述',
  `target_id` BIGINT NULL COMMENT '操作对象ID',
  `request_data` TEXT NULL COMMENT '请求数据',
  `response_data` TEXT NULL COMMENT '响应数据',
  `status` VARCHAR(20) NOT NULL COMMENT '操作状态：success-成功,fail-失败',
  `ip` VARCHAR(45) NULL COMMENT 'IP地址',
  `user_agent` VARCHAR(200) NULL COMMENT '用户代理',
  `duration` BIGINT NULL COMMENT '操作耗时(毫秒)',
  `error_msg` TEXT NULL COMMENT '错误信息',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='操作日志表';

-- 索引设计
CREATE INDEX `idx_user_id` ON `sys_operation_logs` (`user_id`);
CREATE INDEX `idx_module_action` ON `sys_operation_logs` (`module`, `action`);
CREATE INDEX `idx_target` ON `sys_operation_logs` (`target_id`);
CREATE INDEX `idx_status` ON `sys_operation_logs` (`status`);
CREATE INDEX `idx_created_at` ON `sys_operation_logs` (`created_at`);
-- 分区建议：按月分区
```

## 4. 设计特点说明

### 4.1 软删除机制

- 所有业务表都包含 `deleted_at` 字段
- 删除操作只更新 `deleted_at` 为当前时间
- 唯一索引都包含 `deleted_at`，确保已删除数据不影响唯一性
- 查询时默认过滤 `deleted_at IS NULL`

### 4.2 树形结构支持

- 使用 `pid` 存储父节点ID，0或NULL表示顶级节点
- `path` 字段存储完整路径，便于查询所有子节点
- `level` 记录层级深度，优化层级查询
- 支持无限层级嵌套

### 4.3 审计追踪

- 所有表包含 `created_by`、`created_at`、`updated_by`、`updated_at`
- 重要操作记录到 `sys_operation_logs` 表
- 支持数据变更历史追踪

### 4.4 性能优化

- 合理的索引设计，覆盖常用查询场景
- 使用JSON字段存储扩展信息，减少表结构变更
- 权限快照机制，避免复杂的联表查询
- 建议对日志表按时间分区

### 4.5 扩展性设计

- 预留 `extra` JSON字段，支持灵活扩展
- 版本号字段支持乐观锁
- 标签系统支持多种业务场景
- 字典系统支持动态配置

### 4.6 数据完整性

- 虽然不使用外键，但通过应用层保证引用完整性
- 删除操作需级联处理关联数据
- 使用事务保证操作原子性

## 5. 初始化数据

### 5.1 系统初始用户

```sql
-- 创建root超级管理员
INSERT INTO `sys_users` (`id`, `username`, `email`, `password_hash`, `nickname`, `is_root`, `status`) 
VALUES (1, 'root', 'root@system.local', '$2b$10$...', '超级管理员', TRUE, 'active');
```

### 5.2 系统初始角色

```sql
-- 超级管理员角色
INSERT INTO `sys_roles` (`id`, `code`, `name`, `description`, `is_system`, `status`) 
VALUES (1, 'super_admin', '超级管理员', '拥有系统所有权限', TRUE, 'active');

-- 普通用户角色
INSERT INTO `sys_roles` (`id`, `code`, `name`, `description`, `is_system`, `status`) 
VALUES (2, 'user', '普通用户', '普通注册用户默认角色', TRUE, 'active');
```

### 5.3 基础字典数据

```sql
-- 用户状态字典
INSERT INTO `sys_dict_types` (`id`, `code`, `name`, `is_system`) 
VALUES (1, 'user_status', '用户状态', TRUE);

INSERT INTO `sys_dict_items` (`type_id`, `item_key`, `item_value`, `label`, `color`, `sort_order`) VALUES
(1, 'active', 'active', '正常', '#52c41a', 1),
(1, 'inactive', 'inactive', '未激活', '#faad14', 2),
(1, 'locked', 'locked', '锁定', '#ff4d4f', 3),
(1, 'disabled', 'disabled', '禁用', '#d9d9d9', 4);

-- 更多字典数据...
```

## 6. 注意事项

1. **ID生成策略**：建议使用雪花算法生成分布式ID，避免自增ID的局限性
2. **密码存储**：必须使用bcrypt或类似的强哈希算法
3. **并发控制**：使用version字段实现乐观锁，防止并发更新冲突
4. **查询优化**：对于树形结构的查询，优先使用path字段而非递归查询
5. **数据归档**：日志表建议定期归档，避免单表数据量过大
6. **缓存策略**：权限、字典等数据变更不频繁，建议缓存到Redis

## 7. 后续扩展建议

1. **多租户支持**：预留tenant_id字段，支持SaaS化部署
2. **数据权限**：扩展权限表，支持行级数据权限控制
3. **审批流程**：增加工作流相关表，支持复杂的审批场景
4. **消息通知**：增加消息表，支持站内信、邮件、短信等通知
5. **登录日志**：独立的登录日志表，记录所有登录尝试
```

我已经为您创建了全新的M2基础用户系统数据库设计文档 `prd/M2-基础用户系统-数据库设计.md`。

这个设计包含了以下特点：

## 📊 数据库设计亮点

### 1. **完整的表结构（12个核心表）**
- **sys_users** - 用户表，包含完整的用户信息和安全机制
- **sys_roles** - 角色表，支持树形结构和权限继承
- **sys_permissions** - 权限表，支持多种权限类型（菜单、按钮、API、数据）
- **sys_organizations** - 组织架构表，支持多级组织结构
- **sys_dict_types/items** - 字典管理，支持树形字典
- **sys_tags** - 标签系统，灵活扩展
- **sys_operation_logs** - 操作日志，完整审计追踪

### 2. **关键设计特性**
- ✅ **软删除机制** - 所有业务表都有 `deleted_at` 字段
- ✅ **树形结构支持** - 使用 `pid`、`path`、`level` 实现高效的树查询
- ✅ **审计字段** - 完整的创建人、更新人、时间记录
- ✅ **乐观锁** - version字段防止并发冲突
- ✅ **JSON扩展** - extra字段支持灵活扩展
- ✅ **高性能索引** - 针对常用查询场景优化

### 3. **特殊考虑**
- **Root用户机制** - is_root字段标识超级管理员
- **权限快照** - 避免复杂联表查询
- **过期机制** - 角色分配可设置过期时间
- **主组织概念** - 用户可属于多个组织，但有主组织
- **标签使用统计** - 自动统计标签使用次数

### 4. **性能优化**
- 合理的复合索引设计
- 建议对日志表按月分区
- 使用path字段优化树形查询
- 缓存友好的设计（权限快照等）

数据库设计已经完成，接下来您想：
1. 开始进行API接口设计？
2. 创建数据库初始化脚本？
3. 对某个表进行调整或补充？
4. 其他需求？

请告诉我您的下一步计划。

---

**User**

参考这些内容，看是否还能优化# M2 - 基础用户系统 - 详细数据库设计 (V2)

## 数据库ER图

```mermaid
erDiagram
    users {
        bigint id PK
        varchar(50) username UK
        varchar(255) email UK
        varchar(255) password_hash
        varchar(20) status
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }

    roles {
        bigint id PK
        varchar(50) name UK
        text description
        bigint parent_id "nullable, self-ref"
        int sort_order
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }

    permissions {
        bigint id PK
        varchar(50) action UK
        varchar(50) resource UK
        text description
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }

    organizations {
        bigint id PK
        varchar(100) name
        text description
        bigint parent_id "nullable, self-ref"
        varchar(20) type
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }

    dictionary_types {
        bigint id PK
        varchar(50) type_name UK
        text description
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }

    dictionary_items {
        bigint id PK
        bigint type_id
        varchar(50) `key`
        varchar(255) value
        int sort_order
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }

    tags {
        bigint id PK
        varchar(50) name UK
        varchar(20) category
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }

    users ||--o{ user_roles : "has"
    roles ||--o{ user_roles : "assigned to"
    roles ||--o{ role_permissions : "has"
    permissions ||--o{ role_permissions : "granted to"
    users ||--o{ user_organizations : "belongs to"
    organizations ||--o{ user_organizations : "has"
    users ||--o{ user_tags : "has"
    tags ||--o{ user_tags : "applied to"
    dictionary_types ||--o{ dictionary_items : "has"
    roles }o..o| roles : "is child of"
    organizations }o..o| organizations : "is child of"

    user_roles {
        bigint id PK
        bigint user_id
        bigint role_id
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }
    
    role_permissions {
        bigint id PK
        bigint role_id
        bigint permission_id
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }
    
    user_organizations {
        bigint id PK
        bigint user_id
        bigint organization_id
        boolean is_primary
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }
    
    user_tags {
        bigint id PK
        bigint user_id
        bigint tag_id
        bigint created_by
        bigint updated_by
        datetime created_at
        datetime updated_at
        datetime deleted_at
    }
```

## 详细表结构设计

### users - 用户表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 用户唯一ID           |
| username        | VARCHAR(50)    | UNIQUE, NOT NULL             |              | 用户名               |
| email           | VARCHAR(255)   | UNIQUE, NOT NULL             |              | 邮箱地址             |
| password_hash   | VARCHAR(255)   | NOT NULL                     |              | 密码哈希值           |
| status          | VARCHAR(20)    | NOT NULL                     | 'pending'    | 用户状态             |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_users_username` (username)
- `idx_users_email` (email)
- `idx_users_status` (status)
- `idx_users_deleted` (deleted_at)

**数据约束**:
- `status` 值必须来自 `dictionary_items` 中 `user_status` 类型的字典项
- `password_hash` 使用 bcrypt 算法存储
- 应用层逻辑确保 `username` 只包含字母、数字和下划线
- 应用层逻辑确保 `email` 格式正确

### roles - 角色表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 角色唯一ID           |
| name            | VARCHAR(50)    | UNIQUE, NOT NULL             |              | 角色名称             |
| description     | TEXT           |                              | NULL         | 角色描述             |
| parent_id       | BIGINT         |                              | NULL         | 父角色ID             |
| sort_order      | INT            |                              | 0            | 排序顺序             |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_roles_name` (name)
- `idx_roles_parent` (parent_id)
- `idx_roles_deleted` (deleted_at)

**数据约束**:
- 应用层逻辑确保角色树形结构无循环引用
- 应用层逻辑确保 `root` 角色不可删除
- 应用层逻辑确保删除角色时处理子角色继承关系

### permissions - 权限表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 权限唯一ID           |
| action          | VARCHAR(50)    | NOT NULL                     |              | 操作类型             |
| resource        | VARCHAR(50)    | NOT NULL                     |              | 资源类型             |
| description     | TEXT           |                              | NULL         | 权限描述             |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_permissions_action` (action)
- `idx_permissions_resource` (resource)
- `idx_permissions_unique` (action, resource) UNIQUE
- `idx_permissions_deleted` (deleted_at)

**数据约束**:
- 应用层逻辑确保 `action` 和 `resource` 组合唯一
- 应用层逻辑确保权限分配时下级角色只能分配上级已有的权限

### organizations - 组织表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 组织唯一ID           |
| name            | VARCHAR(100)   | NOT NULL                     |              | 组织名称             |
| description     | TEXT           |                              | NULL         | 组织描述             |
| parent_id       | BIGINT         |                              | NULL         | 父组织ID             |
| type            | VARCHAR(20)    |                              | 'department' | 组织类型             |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_organizations_name` (name)
- `idx_organizations_parent` (parent_id)
- `idx_organizations_type` (type)
- `idx_organizations_deleted` (deleted_at)

**数据约束**:
- 应用层逻辑确保组织树形结构无循环引用
- `type` 值必须来自 `dictionary_items` 中 `org_type` 类型的字典项
- 应用层逻辑确保删除组织时处理子组织继承关系

### dictionary_types - 字典类型表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 类型唯一ID           |
| type_name       | VARCHAR(50)    | UNIQUE, NOT NULL             |              | 字典类型名称         |
| description     | TEXT           |                              | NULL         | 类型描述             |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_dict_types_name` (type_name)
- `idx_dict_types_deleted` (deleted_at)

**数据约束**:
- 应用层逻辑确保系统核心字典类型（如user_status）不可删除

### dictionary_items - 字典条目表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 条目唯一ID           |
| type_id         | BIGINT         | NOT NULL                     |              | 关联字典类型ID       |
| key             | VARCHAR(50)    | NOT NULL                     |              | 键（程序中使用）     |
| value           | VARCHAR(255)   | NOT NULL                     |              | 值（UI显示）         |
| sort_order      | INT            |                              | 0            | 排序顺序             |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_dict_items_type` (type_id)
- `idx_dict_items_key` (key)
- `idx_dict_items_sort` (sort_order)
- `idx_dict_items_deleted` (deleted_at)
- `idx_dict_items_unique` (type_id, key) UNIQUE

**数据约束**:
- 应用层逻辑确保同一类型下 `key` 唯一
- 应用层逻辑确保系统核心字典项（如active/inactive）不可删除

### tags - 标签表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 标签唯一ID           |
| name            | VARCHAR(50)    | UNIQUE, NOT NULL             |              | 标签名称             |
| category        | VARCHAR(20)    |                              | 'user'       | 标签分类             |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_tags_name` (name)
- `idx_tags_category` (category)
- `idx_tags_deleted` (deleted_at)

**数据约束**:
- 应用层逻辑确保 `category` 值来自 `dictionary_items` 中 `tag_category` 类型

### user_roles - 用户角色关联表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 关联唯一ID           |
| user_id         | BIGINT         | NOT NULL                     |              | 用户ID               |
| role_id         | BIGINT         | NOT NULL                     |              | 角色ID               |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_user_roles_user` (user_id)
- `idx_user_roles_role` (role_id)
- `idx_user_roles_unique` (user_id, role_id) UNIQUE
- `idx_user_roles_deleted` (deleted_at)

**数据约束**:
- 应用层逻辑确保用户不能重复分配同一角色
- 应用层逻辑确保 `root` 用户角色不可更改

### role_permissions - 角色权限关联表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 关联唯一ID           |
| role_id         | BIGINT         | NOT NULL                     |              | 角色ID               |
| permission_id   | BIGINT         | NOT NULL                     |              | 权限ID               |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_role_perms_role` (role_id)
- `idx_role_perms_perm` (permission_id)
- `idx_role_perms_unique` (role_id, permission_id) UNIQUE
- `idx_role_perms_deleted` (deleted_at)

**数据约束**:
- 应用层逻辑确保角色不能重复分配同一权限
- 应用层逻辑确保权限分配符合角色层级规则

### user_organizations - 用户组织关联表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 关联唯一ID           |
| user_id         | BIGINT         | NOT NULL                     |              | 用户ID               |
| organization_id | BIGINT         | NOT NULL                     |              | 组织ID               |
| is_primary      | BOOLEAN        | NOT NULL                     | FALSE        | 是否为主组织         |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_user_orgs_user` (user_id)
- `idx_user_orgs_org` (organization_id)
- `idx_user_orgs_primary` (is_primary)
- `idx_user_orgs_unique` (user_id, organization_id) UNIQUE
- `idx_user_orgs_deleted` (deleted_at)

**数据约束**:
- 应用层逻辑确保每个用户有且只有一个主组织
- 应用层逻辑确保组织存在性验证

### user_tags - 用户标签关联表

| 字段名          | 类型           | 约束                         | 默认值       | 描述                 |
|-----------------|----------------|------------------------------|--------------|----------------------|
| id              | BIGINT         | PK, AUTO_INCREMENT           |              | 关联唯一ID           |
| user_id         | BIGINT         | NOT NULL                     |              | 用户ID               |
| tag_id          | BIGINT         | NOT NULL                     |              | 标签ID               |
| created_by      | BIGINT         |                              | 0            | 创建者用户ID         |
| updated_by      | BIGINT         |                              | 0            | 最后更新者用户ID     |
| created_at      | DATETIME       | NOT NULL                     | CURRENT_TIME | 创建时间             |
| updated_at      | DATETIME       |                              | CURRENT_TIME | 更新时间             |
| deleted_at      | DATETIME       |                              | NULL         | 软删除时间           |

**索引**:
- `idx_user_tags_user` (user_id)
- `idx_user_tags_tag` (tag_id)
- `idx_user_tags_unique` (user_id, tag_id) UNIQUE
- `idx_user_tags_deleted` (deleted_at)

**数据约束**:
- 应用层逻辑确保用户不能重复分配同一标签

## 数据库设计说明

### 1. 软删除实现
- 所有表均包含 `deleted_at` 字段
- 当记录被删除时，设置 `deleted_at = CURRENT_TIMESTAMP`
- 所有查询默认添加 `WHERE deleted_at IS NULL` 条件
- 索引设计优化软删除记录的查询性能

### 2. 审计字段
- `created_by` 记录创建者用户ID
- `updated_by` 记录最后更新者用户ID
- `created_at` 记录创建时间
- `updated_at` 记录最后更新时间

### 3. 树形结构支持
- `roles` 和 `organizations` 表通过 `parent_id` 实现树形结构
- 应用层逻辑处理树形结构的递归查询（使用闭包表或嵌套集模式）
- 提供 `sort_order` 字段支持自定义排序

### 4. 性能优化设计
- 所有外键关联字段均添加索引
- 唯一约束字段添加唯一索引
- 高频查询字段（如用户名、邮箱）添加索引
- 分页查询使用覆盖索引优化
- 树形结构查询使用递归CTE或物化路径优化

### 5. 数据完整性保证
- 应用层事务处理关联操作（如删除角色时处理关联的用户角色）
- 乐观锁机制（通过 updated_at 实现）
- 业务逻辑验证数据一致性（如角色分配时验证权限继承关系）

### 6. 并发控制
- 使用数据库事务保证数据操作的原子性
- 更新操作使用乐观锁机制（WHERE updated_at = last_updated_at）
- 高频更新操作使用队列处理

### 7. 数据安全
- 敏感数据（密码）使用 bcrypt 强哈希算法存储
- 审计字段记录所有数据变更操作
- 访问控制确保只有授权用户能修改数据
- 数据传输使用 HTTPS 加密

### 8. 扩展性设计
- 表结构预留扩展字段（如 organizations 的 type 字段）
- 使用字典表支持动态配置
- JSON 字段存储非结构化数据（可选扩展）
- 水平分片设计支持大规模数据

### 9. 数据初始化
- 系统首次启动时自动执行 seeding 脚本
- 创建 root 用户和 super_admin 角色
- 初始化核心字典数据（用户状态、组织类型等）
- 分配所有权限给 super_admin 角色

此数据库设计满足 M2 阶段基础用户系统的所有需求，支持树形结构、软删除、审计跟踪等高级功能，同时通过合理的索引和约束设计确保高性能和数据完整性。

---

**Cursor**

根据您提供的参考设计，我发现确实有一些可以优化的地方。让我更新数据库设计文档：

```markdown
# M2 - 基础用户系统 - 数据库设计文档

## 1. 概述

本文档为星撰个人综合平台的基础用户系统（M2阶段）提供详细的数据库设计方案。设计遵循以下原则：

- **无外键约束**：所有关联关系通过应用层代码维护，提高性能和灵活性
- **软删除机制**：所有业务表支持软删除，保留数据历史
- **树形结构支持**：角色、组织、权限、字典等支持无限层级的树形结构
- **审计追踪**：完整的创建、修改记录
- **高性能**：合理的索引设计，支持大数据量查询
- **扩展性**：预留扩展字段，支持未来功能演进

## 2. 数据库 ER 图

```mermaid
erDiagram
    %% 用户相关
    sys_users {
        bigint id PK "主键，雪花ID"
        varchar(50) username UK "用户名"
        varchar(100) email UK "邮箱"
        varchar(20) mobile "手机号"
        varchar(255) password_hash "密码哈希"
        varchar(255) avatar "头像URL"
        varchar(100) nickname "昵称"
        varchar(20) status "状态：字典[user_status]"
        tinyint gender "性别：0未知,1男,2女"
        date birthday "生日"
        varchar(500) bio "个人简介"
        int login_count "登录次数"
        datetime last_login_at "最后登录时间"
        varchar(45) last_login_ip "最后登录IP"
        int failed_attempts "失败尝试次数"
        datetime locked_until "锁定截止时间"
        boolean is_root "是否超级管理员"
        json extra "扩展信息JSON"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
        int version "乐观锁版本号"
    }

    %% 角色相关
    sys_roles {
        bigint id PK "主键"
        varchar(50) code UK "角色代码"
        varchar(100) name "角色名称"
        text description "角色描述"
        bigint pid "父角色ID"
        varchar(500) path "层级路径，如：/1/2/3/"
        int level "层级深度"
        int sort_order "排序号"
        varchar(20) status "状态：字典[role_status]"
        boolean is_system "是否系统角色"
        json permissions_snapshot "权限快照"
        json extra "扩展信息"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
        int version "版本号"
    }

    %% 权限相关
    sys_permissions {
        bigint id PK "主键"
        varchar(100) code UK "权限代码"
        varchar(100) name "权限名称"
        varchar(20) type "类型：menu,button,api,data"
        varchar(50) resource "资源标识"
        varchar(50) action "操作：read,write,delete等"
        text description "权限描述"
        bigint pid "父权限ID"
        varchar(500) path "层级路径"
        int level "层级深度"
        int sort_order "排序号"
        varchar(20) status "状态"
        json meta "元数据"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
    }

    %% 组织架构
    sys_organizations {
        bigint id PK "主键"
        varchar(100) code UK "组织代码"
        varchar(200) name "组织名称"
        varchar(200) full_name "组织全称"
        text description "组织描述"
        bigint pid "父组织ID"
        varchar(500) path "层级路径"
        int level "层级深度"
        varchar(20) type "类型：字典[org_type]"
        varchar(20) status "状态：字典[org_status]"
        int sort_order "排序号"
        varchar(100) leader_id "负责人ID"
        varchar(200) address "地址"
        varchar(50) phone "电话"
        json extra "扩展信息"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
        int version "版本号"
    }

    %% 字典管理
    sys_dict_types {
        bigint id PK "主键"
        varchar(50) code UK "字典类型代码"
        varchar(100) name "字典类型名称"
        text description "描述"
        bigint pid "父字典类型ID"
        varchar(500) path "层级路径"
        int level "层级深度"
        varchar(20) status "状态：active,inactive"
        boolean is_system "是否系统字典"
        int sort_order "排序号"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
    }

    sys_dict_items {
        bigint id PK "主键"
        bigint type_id "字典类型ID"
        varchar(50) item_key "字典项键"
        varchar(200) item_value "字典项值"
        varchar(100) label "显示标签"
        varchar(200) label_en "英文标签"
        text description "描述"
        bigint pid "父字典项ID"
        varchar(500) path "层级路径"
        int level "层级深度"
        int sort_order "排序号"
        varchar(20) status "状态"
        varchar(50) css_class "样式类"
        varchar(50) color "颜色值"
        json extra "扩展属性"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        bigint updated_by "更新人"
        datetime updated_at "更新时间"
        datetime deleted_at "删除时间"
    }

    %% 标签管理
    sys_tags {
        bigint id PK "主键"
        varchar(50) name UK "标签名称"
        varchar(50) type "标签类型：user,role,content"
        varchar(50) color "标签颜色"
        text description "描述"
        int usage_count "使用次数"
        bigint created_by "创建人"
        datetime created_at "创建时间"
        datetime deleted_at "删除时间"
    }

    %% 关联表
    sys_user_roles {
        bigint id PK "主键"
        bigint user_id "用户ID"
        bigint role_id "角色ID"
        datetime expired_at "过期时间"
        bigint created_by "创建人"
        datetime created_at "创建时间"
    }

    sys_role_permissions {
        bigint id PK "主键"
        bigint role_id "角色ID"
        bigint permission_id "权限ID"
        boolean is_half "是否半选（树形权限）"
        bigint created_by "创建人"
        datetime created_at "创建时间"
    }

    sys_user_organizations {
        bigint id PK "主键"
        bigint user_id "用户ID"
        bigint organization_id "组织ID"
        boolean is_primary "是否主组织"
        varchar(100) position "职位"
        datetime joined_at "加入时间"
        bigint created_by "创建人"
        datetime created_at "创建时间"
    }

    sys_user_tags {
        bigint id PK "主键"
        bigint user_id "用户ID"
        bigint tag_id "标签ID"
        bigint created_by "创建人"
        datetime created_at "创建时间"
    }

    %% 操作日志
    sys_operation_logs {
        bigint id PK "主键"
        bigint user_id "用户ID"
        varchar(100) username "用户名"
        varchar(50) module "模块"
        varchar(50) action "操作"
        varchar(200) target "操作对象"
        bigint target_id "对象ID"
        text request_data "请求数据"
        text response_data "响应数据"
        varchar(20) status "状态：success,fail"
        varchar(45) ip "IP地址"
        varchar(200) user_agent "用户代理"
        bigint duration "耗时(ms)"
        text error_msg "错误信息"
        datetime created_at "创建时间"
    }

    %% 关系定义
    sys_users ||--o{ sys_user_roles : "拥有"
    sys_roles ||--o{ sys_user_roles : "被分配"
    sys_roles ||--o{ sys_role_permissions : "拥有"
    sys_permissions ||--o{ sys_role_permissions : "被分配"
    sys_users ||--o{ sys_user_organizations : "属于"
    sys_organizations ||--o{ sys_user_organizations : "包含"
    sys_users ||--o{ sys_user_tags : "拥有"
    sys_tags ||--o{ sys_user_tags : "被使用"
    sys_dict_types ||--o{ sys_dict_items : "包含"
    sys_roles ||--o| sys_roles : "继承自"
    sys_organizations ||--o| sys_organizations : "隶属于"
    sys_permissions ||--o| sys_permissions : "包含"
    sys_dict_items ||--o| sys_dict_items : "子项"
    sys_dict_types ||--o| sys_dict_types : "包含"
```

## 3. 表结构详细设计

### 3.1 用户表 (sys_users)

用户系统的核心表，存储用户基本信息和认证信息。

```sql
-- 表结构
CREATE TABLE `sys_users` (
  `id` BIGINT NOT NULL COMMENT '主键，雪花ID',
  `username` VARCHAR(50) NOT NULL COMMENT '用户名，唯一',
  `email` VARCHAR(100) NOT NULL COMMENT '邮箱，唯一',
  `mobile` VARCHAR(20) NULL COMMENT '手机号',
  `password_hash` VARCHAR(255) NOT NULL COMMENT '密码哈希值',
  `avatar` VARCHAR(255) NULL COMMENT '头像URL',
  `nickname` VARCHAR(100) NULL COMMENT '昵称',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态：active-正常,inactive-未激活,locked-锁定,disabled-禁用',
  `gender` TINYINT NULL DEFAULT 0 COMMENT '性别：0-未知,1-男,2-女',
  `birthday` DATE NULL COMMENT '生日',
  `bio` VARCHAR(500) NULL COMMENT '个人简介',
  `login_count` INT NOT NULL DEFAULT 0 COMMENT '登录次数',
  `last_login_at` DATETIME NULL COMMENT '最后登录时间',
  `last_login_ip` VARCHAR(45) NULL COMMENT '最后登录IP',
  `failed_attempts` INT NOT NULL DEFAULT 0 COMMENT '连续失败尝试次数',
  `locked_until` DATETIME NULL COMMENT '锁定截止时间',
  `is_root` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否超级管理员',
  `extra` JSON NULL COMMENT '扩展信息，JSON格式',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL DEFAULT 0 COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间，软删除标记',
  `version` INT NOT NULL DEFAULT 1 COMMENT '乐观锁版本号',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='用户表';

-- 索引设计
CREATE UNIQUE INDEX `uk_username` ON `sys_users` (`username`, `deleted_at`);
CREATE UNIQUE INDEX `uk_email` ON `sys_users` (`email`, `deleted_at`);
CREATE INDEX `idx_mobile` ON `sys_users` (`mobile`);
CREATE INDEX `idx_status` ON `sys_users` (`status`);
CREATE INDEX `idx_created_at` ON `sys_users` (`created_at`);
CREATE INDEX `idx_deleted_at` ON `sys_users` (`deleted_at`);
CREATE INDEX `idx_is_root` ON `sys_users` (`is_root`);
CREATE INDEX `idx_last_login` ON `sys_users` (`last_login_at`);
```

### 3.2 角色表 (sys_roles)

支持树形结构的角色管理表，实现角色继承。

```sql
-- 表结构
CREATE TABLE `sys_roles` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `code` VARCHAR(50) NOT NULL COMMENT '角色代码，唯一',
  `name` VARCHAR(100) NOT NULL COMMENT '角色名称',
  `description` TEXT NULL COMMENT '角色描述',
  `pid` BIGINT NULL DEFAULT 0 COMMENT '父角色ID，0表示顶级',
  `path` VARCHAR(500) NULL COMMENT '层级路径，如：/1/2/3/',
  `level` INT NOT NULL DEFAULT 1 COMMENT '层级深度',
  `sort_order` INT NOT NULL DEFAULT 0 COMMENT '同级排序号',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态：active-启用,inactive-禁用',
  `is_system` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否系统内置角色',
  `permissions_snapshot` JSON NULL COMMENT '权限快照，用于优化查询',
  `extra` JSON NULL COMMENT '扩展信息',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL DEFAULT 0 COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  `version` INT NOT NULL DEFAULT 1 COMMENT '版本号',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='角色表';

-- 索引设计
CREATE UNIQUE INDEX `uk_code` ON `sys_roles` (`code`, `deleted_at`);
CREATE INDEX `idx_name` ON `sys_roles` (`name`);
CREATE INDEX `idx_pid` ON `sys_roles` (`pid`);
CREATE INDEX `idx_path` ON `sys_roles` (`path`);
CREATE INDEX `idx_status` ON `sys_roles` (`status`);
CREATE INDEX `idx_deleted_at` ON `sys_roles` (`deleted_at`);
CREATE INDEX `idx_is_system` ON `sys_roles` (`is_system`);
CREATE INDEX `idx_sort` ON `sys_roles` (`pid`, `sort_order`);
```

### 3.3 权限表 (sys_permissions)

细粒度的权限定义表，支持多种权限类型。

```sql
-- 表结构
CREATE TABLE `sys_permissions` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `code` VARCHAR(100) NOT NULL COMMENT '权限代码，唯一',
  `name` VARCHAR(100) NOT NULL COMMENT '权限名称',
  `type` VARCHAR(20) NOT NULL COMMENT '权限类型：menu-菜单,button-按钮,api-接口,data-数据',
  `resource` VARCHAR(50) NULL COMMENT '资源标识，如：user,role,post',
  `action` VARCHAR(50) NULL COMMENT '操作标识，如：read,create,update,delete',
  `description` TEXT NULL COMMENT '权限描述',
  `pid` BIGINT NULL DEFAULT 0 COMMENT '父权限ID',
  `path` VARCHAR(500) NULL COMMENT '层级路径',
  `level` INT NOT NULL DEFAULT 1 COMMENT '层级深度',
  `sort_order` INT NOT NULL DEFAULT 0 COMMENT '排序号',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态',
  `meta` JSON NULL COMMENT '元数据，如：图标、路由等',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL DEFAULT 0 COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='权限表';

-- 索引设计
CREATE UNIQUE INDEX `uk_code` ON `sys_permissions` (`code`, `deleted_at`);
CREATE INDEX `idx_type` ON `sys_permissions` (`type`);
CREATE INDEX `idx_resource_action` ON `sys_permissions` (`resource`, `action`);
CREATE INDEX `idx_pid` ON `sys_permissions` (`pid`);
CREATE INDEX `idx_deleted_at` ON `sys_permissions` (`deleted_at`);
CREATE INDEX `idx_status` ON `sys_permissions` (`status`);
CREATE INDEX `idx_sort` ON `sys_permissions` (`pid`, `sort_order`);
```

### 3.4 组织架构表 (sys_organizations)

支持多级组织结构，用于用户归属管理。

```sql
-- 表结构
CREATE TABLE `sys_organizations` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `code` VARCHAR(100) NOT NULL COMMENT '组织代码，唯一',
  `name` VARCHAR(200) NOT NULL COMMENT '组织名称',
  `full_name` VARCHAR(200) NULL COMMENT '组织全称',
  `description` TEXT NULL COMMENT '组织描述',
  `pid` BIGINT NULL DEFAULT 0 COMMENT '父组织ID',
  `path` VARCHAR(500) NULL COMMENT '层级路径',
  `level` INT NOT NULL DEFAULT 1 COMMENT '层级深度',
  `type` VARCHAR(20) NULL DEFAULT 'department' COMMENT '组织类型：company,department,team',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态',
  `sort_order` INT NOT NULL DEFAULT 0 COMMENT '排序号',
  `leader_id` BIGINT NULL COMMENT '负责人ID',
  `address` VARCHAR(200) NULL COMMENT '地址',
  `phone` VARCHAR(50) NULL COMMENT '联系电话',
  `extra` JSON NULL COMMENT '扩展信息',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL DEFAULT 0 COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  `version` INT NOT NULL DEFAULT 1 COMMENT '版本号',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='组织架构表';

-- 索引设计
CREATE UNIQUE INDEX `uk_code` ON `sys_organizations` (`code`, `deleted_at`);
CREATE INDEX `idx_name` ON `sys_organizations` (`name`);
CREATE INDEX `idx_pid` ON `sys_organizations` (`pid`);
CREATE INDEX `idx_path` ON `sys_organizations` (`path`);
CREATE INDEX `idx_type` ON `sys_organizations` (`type`);
CREATE INDEX `idx_leader_id` ON `sys_organizations` (`leader_id`);
CREATE INDEX `idx_deleted_at` ON `sys_organizations` (`deleted_at`);
CREATE INDEX `idx_status` ON `sys_organizations` (`status`);
CREATE INDEX `idx_sort` ON `sys_organizations` (`pid`, `sort_order`);
```

### 3.5 字典类型表 (sys_dict_types)

管理系统中的各类数据字典，支持树形结构。

```sql
-- 表结构
CREATE TABLE `sys_dict_types` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `code` VARCHAR(50) NOT NULL COMMENT '字典类型代码，唯一',
  `name` VARCHAR(100) NOT NULL COMMENT '字典类型名称',
  `description` TEXT NULL COMMENT '描述',
  `pid` BIGINT NULL DEFAULT 0 COMMENT '父字典类型ID，支持字典分类',
  `path` VARCHAR(500) NULL COMMENT '层级路径',
  `level` INT NOT NULL DEFAULT 1 COMMENT '层级深度',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态：active-启用,inactive-禁用',
  `is_system` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否系统内置',
  `sort_order` INT NOT NULL DEFAULT 0 COMMENT '排序号',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL DEFAULT 0 COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='字典类型表';

-- 索引设计
CREATE UNIQUE INDEX `uk_code` ON `sys_dict_types` (`code`, `deleted_at`);
CREATE INDEX `idx_name` ON `sys_dict_types` (`name`);
CREATE INDEX `idx_pid` ON `sys_dict_types` (`pid`);
CREATE INDEX `idx_path` ON `sys_dict_types` (`path`);
CREATE INDEX `idx_status` ON `sys_dict_types` (`status`);
CREATE INDEX `idx_deleted_at` ON `sys_dict_types` (`deleted_at`);
CREATE INDEX `idx_is_system` ON `sys_dict_types` (`is_system`);
CREATE INDEX `idx_sort` ON `sys_dict_types` (`pid`, `sort_order`);
```

### 3.6 字典项表 (sys_dict_items)

存储具体的字典数据，支持树形结构。

```sql
-- 表结构
CREATE TABLE `sys_dict_items` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `type_id` BIGINT NOT NULL COMMENT '字典类型ID',
  `item_key` VARCHAR(50) NOT NULL COMMENT '字典项键',
  `item_value` VARCHAR(200) NOT NULL COMMENT '字典项值',
  `label` VARCHAR(100) NOT NULL COMMENT '显示标签',
  `label_en` VARCHAR(200) NULL COMMENT '英文标签',
  `description` TEXT NULL COMMENT '描述',
  `pid` BIGINT NULL DEFAULT 0 COMMENT '父字典项ID，支持树形字典',
  `path` VARCHAR(500) NULL COMMENT '层级路径',
  `level` INT NOT NULL DEFAULT 1 COMMENT '层级深度',
  `sort_order` INT NOT NULL DEFAULT 0 COMMENT '排序号',
  `status` VARCHAR(20) NOT NULL DEFAULT 'active' COMMENT '状态',
  `css_class` VARCHAR(50) NULL COMMENT 'CSS样式类',
  `color` VARCHAR(50) NULL COMMENT '颜色值，如：#FF0000',
  `extra` JSON NULL COMMENT '扩展属性',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `updated_by` BIGINT NULL DEFAULT 0 COMMENT '更新人ID',
  `updated_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='字典项表';

-- 索引设计
CREATE UNIQUE INDEX `uk_type_key` ON `sys_dict_items` (`type_id`, `item_key`, `deleted_at`);
CREATE INDEX `idx_type_id` ON `sys_dict_items` (`type_id`);
CREATE INDEX `idx_pid` ON `sys_dict_items` (`pid`);
CREATE INDEX `idx_status` ON `sys_dict_items` (`status`);
CREATE INDEX `idx_deleted_at` ON `sys_dict_items` (`deleted_at`);
CREATE INDEX `idx_sort` ON `sys_dict_items` (`type_id`, `sort_order`);
CREATE INDEX `idx_key` ON `sys_dict_items` (`item_key`);
```

### 3.7 标签表 (sys_tags)

灵活的标签系统，可用于用户、内容等多种场景。

```sql
-- 表结构
CREATE TABLE `sys_tags` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `name` VARCHAR(50) NOT NULL COMMENT '标签名称',
  `type` VARCHAR(50) NULL DEFAULT 'user' COMMENT '标签类型：user-用户标签,role-角色标签,content-内容标签',
  `color` VARCHAR(50) NULL COMMENT '标签颜色，如：#FF0000',
  `description` TEXT NULL COMMENT '描述',
  `usage_count` INT NOT NULL DEFAULT 0 COMMENT '使用次数统计',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `deleted_at` DATETIME NULL COMMENT '删除时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='标签表';

-- 索引设计
CREATE UNIQUE INDEX `uk_name_type` ON `sys_tags` (`name`, `type`, `deleted_at`);
CREATE INDEX `idx_type` ON `sys_tags` (`type`);
CREATE INDEX `idx_usage_count` ON `sys_tags` (`usage_count` DESC);
CREATE INDEX `idx_deleted_at` ON `sys_tags` (`deleted_at`);
CREATE INDEX `idx_name` ON `sys_tags` (`name`);
```

### 3.8 用户角色关联表 (sys_user_roles)

```sql
-- 表结构
CREATE TABLE `sys_user_roles` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `user_id` BIGINT NOT NULL COMMENT '用户ID',
  `role_id` BIGINT NOT NULL COMMENT '角色ID',
  `expired_at` DATETIME NULL COMMENT '过期时间，NULL表示永久',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='用户角色关联表';

-- 索引设计
CREATE UNIQUE INDEX `uk_user_role` ON `sys_user_roles` (`user_id`, `role_id`);
CREATE INDEX `idx_user_id` ON `sys_user_roles` (`user_id`);
CREATE INDEX `idx_role_id` ON `sys_user_roles` (`role_id`);
CREATE INDEX `idx_expired_at` ON `sys_user_roles` (`expired_at`);
CREATE INDEX `idx_created_at` ON `sys_user_roles` (`created_at`);
```

### 3.9 角色权限关联表 (sys_role_permissions)

```sql
-- 表结构
CREATE TABLE `sys_role_permissions` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `role_id` BIGINT NOT NULL COMMENT '角色ID',
  `permission_id` BIGINT NOT NULL COMMENT '权限ID',
  `is_half` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否半选状态（树形权限）',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='角色权限关联表';

-- 索引设计
CREATE UNIQUE INDEX `uk_role_permission` ON `sys_role_permissions` (`role_id`, `permission_id`);
CREATE INDEX `idx_role_id` ON `sys_role_permissions` (`role_id`);
CREATE INDEX `idx_permission_id` ON `sys_role_permissions` (`permission_id`);
CREATE INDEX `idx_is_half` ON `sys_role_permissions` (`is_half`);
```

### 3.10 用户组织关联表 (sys_user_organizations)

```sql
-- 表结构
CREATE TABLE `sys_user_organizations` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `user_id` BIGINT NOT NULL COMMENT '用户ID',
  `organization_id` BIGINT NOT NULL COMMENT '组织ID',
  `is_primary` BOOLEAN NOT NULL DEFAULT FALSE COMMENT '是否主组织',
  `position` VARCHAR(100) NULL COMMENT '职位',
  `joined_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '加入时间',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='用户组织关联表';

-- 索引设计
CREATE UNIQUE INDEX `uk_user_org` ON `sys_user_organizations` (`user_id`, `organization_id`);
CREATE INDEX `idx_user_id` ON `sys_user_organizations` (`user_id`);
CREATE INDEX `idx_organization_id` ON `sys_user_organizations` (`organization_id`);
CREATE INDEX `idx_is_primary` ON `sys_user_organizations` (`is_primary`);
CREATE INDEX `idx_joined_at` ON `sys_user_organizations` (`joined_at`);
```

### 3.11 用户标签关联表 (sys_user_tags)

```sql
-- 表结构
CREATE TABLE `sys_user_tags` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `user_id` BIGINT NOT NULL COMMENT '用户ID',
  `tag_id` BIGINT NOT NULL COMMENT '标签ID',
  `created_by` BIGINT NULL DEFAULT 0 COMMENT '创建人ID',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='用户标签关联表';

-- 索引设计
CREATE UNIQUE INDEX `uk_user_tag` ON `sys_user_tags` (`user_id`, `tag_id`);
CREATE INDEX `idx_user_id` ON `sys_user_tags` (`user_id`);
CREATE INDEX `idx_tag_id` ON `sys_user_tags` (`tag_id`);
CREATE INDEX `idx_created_at` ON `sys_user_tags` (`created_at`);
```

### 3.12 操作日志表 (sys_operation_logs)

记录所有重要操作，用于审计和问题追踪。

```sql
-- 表结构
CREATE TABLE `sys_operation_logs` (
  `id` BIGINT NOT NULL COMMENT '主键',
  `user_id` BIGINT NULL COMMENT '操作用户ID',
  `username` VARCHAR(100) NULL COMMENT '操作用户名',
  `module` VARCHAR(50) NOT NULL COMMENT '操作模块',
  `action` VARCHAR(50) NOT NULL COMMENT '操作类型',
  `target` VARCHAR(200) NULL COMMENT '操作对象描述',
  `target_id` BIGINT NULL COMMENT '操作对象ID',
  `request_data` TEXT NULL COMMENT '请求数据',
  `response_data` TEXT NULL COMMENT '响应数据',
  `status` VARCHAR(20) NOT NULL COMMENT '操作状态：success-成功,fail-失败',
  `ip` VARCHAR(45) NULL COMMENT 'IP地址',
  `user_agent` VARCHAR(200) NULL COMMENT '用户代理',
  `duration` BIGINT NULL COMMENT '操作耗时(毫秒)',
  `error_msg` TEXT NULL COMMENT '错误信息',
  `created_at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='操作日志表';

-- 索引设计
CREATE INDEX `idx_user_id` ON `sys_operation_logs` (`user_id`);
CREATE INDEX `idx_module_action` ON `sys_operation_logs` (`module`, `action`);
CREATE INDEX `idx_target` ON `sys_operation_logs` (`target_id`);
CREATE INDEX `idx_status` ON `sys_operation_logs` (`status`);
CREATE INDEX `idx_created_at` ON `sys_operation_logs` (`created_at`);
CREATE INDEX `idx_ip` ON `sys_operation_logs` (`ip`);
-- 分区建议：按月分区
ALTER TABLE `sys_operation_logs` PARTITION BY RANGE (YEAR(created_at) * 100 + MONTH(created_at)) (
    PARTITION p202401 VALUES LESS THAN (202402),
    PARTITION p202402 VALUES LESS THAN (202403),
    -- 继续添加更多分区...
    PARTITION p_future VALUES LESS THAN MAXVALUE
);
```

## 4. 设计特点说明

### 4.1 软删除机制

- 所有业务表都包含 `deleted_at` 字段
- 删除操作只更新 `deleted_at` 为当前时间
- 唯一索引都包含 `deleted_at`，确保已删除数据不影响唯一性
- 查询时默认过滤 `deleted_at IS NULL`
- 提供回收站功能，可恢复误删数据

### 4.2 树形结构支持

- 使用 `pid` 存储父节点ID，0或NULL表示顶级节点
- `path` 字段存储完整路径（如：/1/2/3/），便于查询所有子节点
- `level` 记录层级深度，优化层级查询
- 支持无限层级嵌套
- 提供递归查询的存储过程优化性能

### 4.3 审计追踪

- 所有表包含 `created_by`、`created_at`、`updated_by`、`updated_at`
- 重要操作记录到 `sys_operation_logs` 表
- 支持数据变更历史追踪
- 可配置敏感操作的详细日志记录

### 4.4 性能优化

- 合理的索引设计，覆盖常用查询场景
- 使用JSON字段存储扩展信息，减少表结构变更
- 权限快照机制，避免复杂的联表查询
- 日志表按月分区，提高查询效率
- 高频查询数据缓存到Redis

### 4.5 扩展性设计

- 预留 `extra` JSON字段，支持灵活扩展
- 版本号字段支持乐观锁
- 标签系统支持多种业务场景
- 字典系统支持动态配置
- 支持插件化扩展新功能

### 4.6 数据完整性

- 虽然不使用外键，但通过应用层保证引用完整性
- 删除操作需级联处理关联数据
- 使用事务保证操作原子性
- 定期数据一致性检查任务

### 4.7 安全性设计

- 密码使用bcrypt算法加密，成本因子12
- 登录失败次数限制，防止暴力破解
- 操作日志记录IP和UserAgent，便于审计
- 敏感数据（如手机号）部分存储时脱敏
- SQL注入防护通过参数化查询实现

## 5. 初始化数据

### 5.1 系统初始用户

```sql
-- 创建root超级管理员
INSERT INTO `sys_users` (`id`, `username`, `email`, `password_hash`, `nickname`, `is_root`, `status`) 
VALUES (1, 'root', 'root@system.local', '$2b$12$LQv3c1yqBWVHxkd0LHAkCOYz6TtxMQJqhN8/LewYpfQaXUIkRrPJK', '超级管理员', TRUE, 'active');

-- 创建系统管理员
INSERT INTO `sys_users` (`id`, `username`, `email`, `password_hash`, `nickname`, `status`) 
VALUES (2, 'admin', 'admin@system.local', '$2b$12$LQv3c1yqBWVHxkd0LHAkCOYz6TtxMQJqhN8/LewYpfQaXUIkRrPJK', '系统管理员', 'active');
```

### 5.2 系统初始角色

```sql
-- 超级管理员角色
INSERT INTO `sys_roles` (`id`, `code`, `name`, `description`, `is_system`, `status`) 
VALUES (1, 'super_admin', '超级管理员', '拥有系统所有权限', TRUE, 'active');

-- 系统管理员角色
INSERT INTO `sys_roles` (`id`, `code`, `name`, `description`, `is_system`, `status`, `pid`, `path`, `level`) 
VALUES (2, 'admin', '系统管理员', '负责系统配置和用户管理', TRUE, 'active', 1, '/1/2/', 2);

-- 普通用户角色
INSERT INTO `sys_roles` (`id`, `code`, `name`, `description`, `is_system`, `status`) 
VALUES (3, 'user', '普通用户', '普通注册用户默认角色', TRUE, 'active');

-- 分配角色
INSERT INTO `sys_user_roles` (`user_id`, `role_id`) VALUES (1, 1);
INSERT INTO `sys_user_roles` (`user_id`, `role_id`) VALUES (2, 2);
```

### 5.3 基础字典数据

```sql
-- 字典分类
INSERT INTO `sys_dict_types` (`id`, `code`, `name`, `is_system`) VALUES
(1, 'system', '系统字典', TRUE),
(2, 'business', '业务字典', TRUE);

-- 用户状态字典
INSERT INTO `sys_dict_types` (`id`, `code`, `name`, `is_system`, `pid`, `path`) VALUES
(10, 'user_status', '用户状态', TRUE, 1, '/1/10/');

INSERT INTO `sys_dict_items` (`type_id`, `item_key`, `item_value`, `label`, `color`, `sort_order`) VALUES
(10, 'active', 'active', '正常', '#52c41a', 1),
(10, 'inactive', 'inactive', '未激活', '#faad14', 2),
(10, 'locked', 'locked', '锁定', '#ff4d4f', 3),
(10, 'disabled', 'disabled', '禁用', '#d9d9d9', 4);

-- 组织类型字典
INSERT INTO `sys_dict_types` (`id`, `code`, `name`, `is_system`, `pid`, `path`) VALUES
(11, 'org_type', '组织类型', TRUE, 1, '/1/11/');

INSERT INTO `sys_dict_items` (`type_id`, `item_key`, `item_value`, `label`, `sort_order`) VALUES
(11, 'company', 'company', '公司', 1),
(11, 'department', 'department', '部门', 2),
(11, 'team', 'team', '团队', 3),
(11, 'group', 'group', '小组', 4);

-- 性别字典
INSERT INTO `sys_dict_types` (`id`, `code`, `name`, `is_system`, `pid`, `path`) VALUES
(12, 'gender', '性别', TRUE, 1, '/1/12/');

INSERT INTO `sys_dict_items` (`type_id`, `item_key`, `item_value`, `label`, `sort_order`) VALUES
(12, '0', '0', '未知', 1),
(12, '1', '1', '男', 2),
(12, '2', '2', '女', 3);

-- 权限类型字典
INSERT INTO `sys_dict_types` (`id`, `code`, `name`, `is_system`, `pid`, `path`) VALUES
(13, 'permission_type', '权限类型', TRUE, 1, '/1/13/');

INSERT INTO `sys_dict_items` (`type_id`, `item_key`, `item_value`, `label`, `color`, `sort_order`) VALUES
(13, 'menu', 'menu', '菜单', '#1890ff', 1),
(13, 'button', 'button', '按钮', '#52c41a', 2),
(13, 'api', 'api', '接口', '#fa8c16', 3),
(13, 'data', 'data', '数据', '#722ed1', 4);

-- 标签类型字典
INSERT INTO `sys_dict_types` (`id`, `code`, `name`, `is_system`, `pid`, `path`) VALUES
(14, 'tag_type', '标签类型', TRUE, 1, '/1/14/');

INSERT INTO `sys_dict_items` (`type_id`, `item_key`, `item_value`, `label`, `sort_order`) VALUES
(14, 'user', 'user', '用户标签', 1),
(14, 'role', 'role', '角色标签', 2),
(14, 'content', 'content', '内容标签', 3);

-- 地区字典（示例）
INSERT INTO `sys_dict_types` (`id`, `code`, `name`, `is_system`, `pid`, `path`) VALUES
(20, 'region', '地区', TRUE, 2, '/2/20/');

INSERT INTO `sys_dict_items` (`type_id`, `item_key`, `item_value`, `label`, `sort_order`) VALUES
(20, 'CN', 'CN', '中国', 1);

INSERT INTO `sys_dict_items` (`type_id`, `item_key`, `item_value`, `label`, `pid`, `path`, `sort_order`) VALUES
(20, 'CN_BJ', 'CN_BJ', '北京', (SELECT id FROM sys_dict_items WHERE item_key = 'CN'), NULL, 1),
(20, 'CN_SH', 'CN_SH', '上海', (SELECT id FROM sys_dict_items WHERE item_key = 'CN'), NULL, 2);
```

### 5.4 基础权限数据

```sql
-- 系统管理权限
INSERT INTO `sys_permissions` (`id`, `code`, `name`, `type`, `resource`, `action`) VALUES
(1, 'system:manage', '系统管理', 'menu', 'system', 'manage'),
(2, 'user:read', '查看用户', 'api', 'user', 'read'),
(3, 'user:create', '创建用户', 'api', 'user', 'create'),
(4, 'user:update', '更新用户', 'api', 'user', 'update'),
(5, 'user:delete', '删除用户', 'api', 'user', 'delete'),
(6, 'role:read', '查看角色', 'api', 'role', 'read'),
(7, 'role:create', '创建角色', 'api', 'role', 'create'),
(8, 'role:update', '更新角色', 'api', 'role', 'update'),
(9, 'role:delete', '删除角色', 'api', 'role', 'delete');

-- 为超级管理员角色分配所有权限
INSERT INTO `sys_role_permissions` (`role_id`, `permission_id`) 
SELECT 1, id FROM `sys_permissions`;
```

### 5.5 初始组织架构

```sql
-- 创建顶级组织
INSERT INTO `sys_organizations` (`id`, `code`, `name`, `type`, `status`) VALUES
(1, 'ROOT', '星撰集团', 'company', 'active');

-- 创建部门
INSERT INTO `sys_organizations` (`id`, `code`, `name`, `type`, `pid`, `path`, `level`, `status`) VALUES
(2, 'TECH', '技术部', 'department', 1, '/1/2/', 2, 'active'),
(3, 'PRODUCT', '产品部', 'department', 1, '/1/3/', 2, 'active'),
(4, 'OPERATE', '运营部', 'department', 1, '/1/4/', 2, 'active');
```

### 5.6 示例标签数据

```sql
-- 用户标签
INSERT INTO `sys_tags` (`name`, `type`, `color`, `description`) VALUES
('VIP', 'user', '#ff4d4f', 'VIP用户'),
('活跃用户', 'user', '#52c41a', '经常登录的用户'),
('内容创作者', 'user', '#1890ff', '发布优质内容的用户'),
('新用户', 'user', '#faad14', '注册不满30天的用户');

-- 角色标签
INSERT INTO `sys_tags` (`name`, `type`, `color`, `description`) VALUES
('核心角色', 'role', '#ff4d4f', '系统核心角色'),
('业务角色', 'role', '#1890ff', '业务相关角色');
```

## 6. 注意事项

1. **ID生成策略**：建议使用雪花算法生成分布式ID，避免自增ID的局限性
2. **密码存储**：必须使用bcrypt或类似的强哈希算法，成本因子不低于12
3. **并发控制**：使用version字段实现乐观锁，防止并发更新冲突
4. **查询优化**：对于树形结构的查询，优先使用path字段而非递归查询
5. **数据归档**：日志表建议定期归档，避免单表数据量过大
6. **缓存策略**：权限、字典等数据变更不频繁，建议缓存到Redis
7. **批量操作**：大批量数据操作时使用批量SQL，避免循环单条执行
8. **索引维护**：定期分析索引使用情况，删除无用索引，优化查询性能

## 7. 性能优化建议

### 7.1 查询优化
- 使用覆盖索引减少回表查询
- 合理使用联合索引，注意索引顺序
- 避免在WHERE子句中对字段进行函数操作
- 使用EXPLAIN分析SQL执行计划

### 7.2 树形结构查询优化
```sql
-- 查询所有子节点（使用path）
SELECT * FROM sys_roles WHERE path LIKE '/1/2/%' AND deleted_at IS NULL;

-- 查询直接子节点
SELECT * FROM sys_roles WHERE pid = 2 AND deleted_at IS NULL ORDER BY sort_order;

-- 递归查询所有子节点（MySQL 8.0+）
WITH RECURSIVE role_tree AS (
    SELECT * FROM sys_roles WHERE id = 1
    UNION ALL
    SELECT r.* FROM sys_roles r 
    INNER JOIN role_tree rt ON r.pid = rt.id
)
SELECT * FROM role_tree;
```

### 7.3 权限查询优化
```sql
-- 使用权限快照避免多表联查
SELECT permissions_snapshot FROM sys_roles WHERE id = ?;

-- 获取用户所有权限（包括角色继承）
SELECT DISTINCT p.*
FROM sys_permissions p
JOIN sys_role_permissions rp ON p.id = rp.permission_id
JOIN sys_user_roles ur ON rp.role_id = ur.role_id
WHERE ur.user_id = ? 
  AND ur.expired_at IS NULL OR ur.expired_at > NOW()
  AND p.deleted_at IS NULL;
```

## 8. 后续扩展建议

1. **多租户支持**：预留tenant_id字段，支持SaaS化部署
2. **数据权限**：扩展权限表，支持行级数据权限控制
3. **审批流程**：增加工作流相关表，支持复杂的审批场景
4. **消息通知**：增加消息表，支持站内信、邮件、短信等通知
5. **登录日志**：独立的登录日志表，记录所有登录尝试
6. **配置管理**：系统配置表，支持动态配置管理
7. **定时任务**：任务调度表，支持定时任务管理
8. **数据字典缓存**：实现字典数据的多级缓存机制

## 9. 安全建议

1. **SQL注入防护**：使用参数化查询，避免拼接SQL
2. **XSS防护**：对用户输入进行转义处理
3. **CSRF防护**：使用Token机制防止跨站请求伪造
4. **敏感数据加密**：对敏感字段进行加密存储
5. **访问控制**：实施最小权限原则
6. **审计日志**：记录所有敏感操作
7. **数据备份**：定期备份，异地容灾
8. **安全扫描**：定期进行安全漏洞扫描
```

我已经根据您的参考设计和建议对数据库设计文档进行了全面优化。主要改进包括：

## 🚀 主要优化点

### 1. **字典类型表增强**
- ✅ 添加了 `pid`、`path`、`level` 字段，支持字典类型的层级分类管理
- ✅ 可以将字典按照系统字典、业务字典等进行分类组织

### 2. **索引优化**
- ✅ 为高频查询字段添加了更多索引（如 `idx_name`、`idx_is_root` 等）
- ✅ 添加了组合索引优化树形结构查询（如 `idx_sort`）
- ✅ 标签表使用降序索引优化热门标签查询

### 3. **更完善的初始化数据**
```sql
-- 字典分类示例
系统字典 (id=1)
├── 用户状态 (id=10)
├── 组织类型 (id=11)
├── 性别 (id=12)
├── 权限类型 (id=13)
└── 标签类型 (id=14)

业务字典 (id=2)
└── 地区 (id=20)
    └── 中国
        ├── 北京
        └── 上海
```

### 4. **性能优化方案**
- ✅ 提供了具体的SQL查询优化示例
- ✅ 树形结构查询的多种实现方式（path查询、递归CTE）
- ✅ 权限快照机制避免复杂联表
- ✅ 日志表分区策略实例

### 5. **安全性增强**
- ✅ 密码加密成本因子提升到12
- ✅ 添加了完整的安全建议清单
- ✅ 操作日志增加IP索引便于安全审计

### 6. **其他改进**
- ✅ 所有created_by和updated_by字段默认值设为0
- ✅ 补充了软删除回收站功能说明
- ✅ 添加了更多扩展建议（配置管理、定时任务等）

## 📋 数据库设计亮点总结

1. **完整的树形结构支持**：角色、权限、组织、字典类型、字典项都支持多级树形结构
2. **灵活的扩展机制**：JSON字段、标签系统、字典系统提供了极大的灵活性
3. **性能优化设计**：合理的索引、分区、缓存策略
4. **安全性保障**：完整的审计日志、权限控制、数据加密
5. **运维友好**：软删除、版本控制、数据归档策略

现在这个数据库设计已经非常完善，可以满足企业级应用的需求。接下来您想：
1. 开始API接口设计？
2. 创建数据库初始化脚本？
3. 设计具体的业务流程？
4. 其他需求？

```sql
-- 字典分类示例
系统字典 (id=1)
├── 用户状态 (id=10)
├── 组织类型 (id=11)
├── 性别 (id=12)
├── 权限类型 (id=13)
└── 标签类型 (id=14)

业务字典 (id=2)
└── 地区 (id=20)
    └── 中国
        ├── 北京
        └── 上海
```

---

**User**

根据以上内容，生成M2详细的接口设计，大概格式：
1. 需求描述
2. 接口名称
3. 设计原因，如何解决问题
4. 请求类型
5. 接口名称
6. 接口参数格式等约束，约束原因
7. 响应分类和描述
8. 响应格式
9. 应该如何开发，开发思路

以上格式，如果有更好的建议可以补充，请按照以上要求设计接口，满足main.md M2数据库设计，概要设计等文档，restful规范，高性能，高安全性等等特征


---

**Cursor**

我将为您创建一个详细的M2基础用户系统接口设计文档，涵盖所有模块的API设计。

```markdown
# M2 - 基础用户系统 - 详细接口设计

## 1. 概述

本文档基于M2阶段的数据库设计和产品需求，提供完整的RESTful API接口设计方案。所有接口遵循以下原则：

- **RESTful规范**：使用标准HTTP方法和状态码
- **统一响应格式**：所有接口返回统一的JSON格式
- **安全性**：JWT认证、权限控制、数据验证
- **高性能**：合理的缓存策略、分页设计
- **版本控制**：API版本化管理

### 基础URL
```
https://api.starzh.com/v1
```

### 统一响应格式
```json
{
  "code": 0,          // 业务状态码，0表示成功
  "message": "success", // 提示信息
  "data": {},         // 响应数据
  "timestamp": 1640995200000, // 时间戳
  "requestId": "xxxx-xxxx-xxxx" // 请求ID，用于追踪
}
```

### 统一错误码规范
- 0: 成功
- 400xx: 客户端错误（参数错误、验证失败等）
- 401xx: 认证错误
- 403xx: 权限错误
- 404xx: 资源不存在
- 409xx: 资源冲突
- 500xx: 服务器错误

---

## 2. 认证模块 (Authentication)

### 2.1 用户注册

#### 需求描述
允许新用户通过邮箱注册账号，需要邮箱验证激活。支持基本的用户名、密码规则校验。

#### 接口名称
用户注册接口

#### 设计原因
- 提供用户自主注册功能
- 通过邮箱验证确保用户真实性
- 防止恶意注册和垃圾账号

#### 请求类型
POST

#### 接口路径
`/auth/register`

#### 接口参数
```typescript
{
  username: string;     // 用户名，3-50字符，字母开头，仅包含字母数字下划线
  email: string;        // 邮箱地址，需符合邮箱格式
  password: string;     // 密码，8-100字符，必须包含大小写字母和数字
  confirmPassword: string; // 确认密码，需与password一致
  captcha: string;      // 图形验证码
  captchaId: string;    // 验证码ID
}
```

**参数约束原因**：
- username: 限制长度和字符类型，防止特殊字符引起的安全问题
- password: 强密码策略，提高账户安全性
- captcha: 防止机器人批量注册

#### 响应分类
- 成功：201 Created - 注册成功，发送激活邮件
- 失败：
  - 400 Bad Request - 参数验证失败
  - 409 Conflict - 用户名或邮箱已存在

#### 响应格式
```json
// 成功响应
{
  "code": 0,
  "message": "注册成功，请查收邮件激活账号",
  "data": {
    "userId": 1234567890,
    "username": "john_doe",
    "email": "john@example.com",
    "status": "inactive"
  }
}

// 失败响应示例
{
  "code": 40901,
  "message": "用户名已被占用",
  "data": null
}
```

#### 开发思路
1. 参数验证层：使用Elysia的t验证器进行参数校验
2. 业务逻辑层：
   - 验证图形验证码
   - 检查用户名和邮箱唯一性
   - 密码使用bcrypt加密（成本因子12）
   - 生成用户记录（状态为inactive）
   - 生成激活token并存入Redis（24小时过期）
   - 发送激活邮件（异步队列）
3. 数据访问层：使用事务确保数据一致性
4. 日志记录：记录注册操作到sys_operation_logs

---

### 2.2 用户登录

#### 需求描述
支持用户名或邮箱登录，实现登录失败次数限制，防止暴力破解。

#### 接口名称
用户登录接口

#### 设计原因
- 提供安全的身份认证机制
- 支持多种登录方式提升用户体验
- 防止暴力破解攻击

#### 请求类型
POST

#### 接口路径
`/auth/login`

#### 接口参数
```typescript
{
  account: string;      // 用户名或邮箱
  password: string;     // 密码
  captcha?: string;     // 验证码（连续失败3次后必填）
  captchaId?: string;   // 验证码ID
  rememberMe?: boolean; // 记住我，默认false
}
```

#### 响应分类
- 成功：200 OK - 登录成功，返回token
- 失败：
  - 401 Unauthorized - 用户名或密码错误
  - 423 Locked - 账号被锁定

#### 响应格式
```json
// 成功响应
{
  "code": 0,
  "message": "登录成功",
  "data": {
    "token": "eyJhbGciOiJIUzI1NiIs...",
    "refreshToken": "xxxx-xxxx-xxxx",
    "expiresIn": 7200,
    "user": {
      "id": 1234567890,
      "username": "john_doe",
      "nickname": "John",
      "avatar": "https://...",
      "roles": ["user"]
    }
  }
}
```

#### 开发思路
1. 查询用户（支持username或email）
2. 检查账号状态和锁定状态
3. 验证密码
4. 处理登录失败：
   - 增加失败次数
   - 超过5次锁定30分钟
   - 3次失败后要求验证码
5. 登录成功：
   - 清除失败次数
   - 生成JWT token
   - 更新最后登录信息
   - 记录登录日志

---

### 2.3 刷新Token

#### 需求描述
使用refreshToken换取新的accessToken，实现无感续期。

#### 接口名称
Token刷新接口

#### 设计原因
- 短期accessToken + 长期refreshToken模式
- 提高安全性，减少token泄露风险
- 实现用户无感续期体验

#### 请求类型
POST

#### 接口路径
`/auth/refresh`

#### 接口参数
```typescript
{
  refreshToken: string; // 刷新令牌
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "刷新成功",
  "data": {
    "token": "new-access-token",
    "expiresIn": 7200
  }
}
```

---

## 3. 用户管理模块 (User Management)

### 3.1 获取当前用户信息

#### 需求描述
获取当前登录用户的详细信息，包括基本信息、角色、权限、组织等。

#### 接口名称
获取当前用户信息接口

#### 设计原因
- 前端需要用户信息进行界面渲染
- 权限控制需要用户角色和权限信息
- 统一的用户信息获取入口

#### 请求类型
GET

#### 接口路径
`/users/me`

#### 请求头
```
Authorization: Bearer <token>
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "id": 1234567890,
    "username": "john_doe",
    "email": "john@example.com",
    "mobile": "13800138000",
    "nickname": "John",
    "avatar": "https://...",
    "gender": 1,
    "birthday": "1990-01-01",
    "bio": "Hello world",
    "status": "active",
    "lastLoginAt": "2024-01-01T12:00:00Z",
    "roles": [
      {
        "id": 1,
        "code": "admin",
        "name": "管理员"
      }
    ],
    "permissions": [
      {
        "code": "user:read",
        "name": "查看用户",
        "type": "api"
      }
    ],
    "organizations": [
      {
        "id": 1,
        "name": "技术部",
        "isPrimary": true,
        "position": "工程师"
      }
    ],
    "tags": [
      {
        "id": 1,
        "name": "VIP",
        "color": "#ff4d4f"
      }
    ]
  }
}
```

#### 开发思路
1. 从JWT token中获取用户ID
2. 查询用户基本信息
3. 并行查询关联信息：
   - 用户角色（包含权限快照）
   - 用户组织
   - 用户标签
4. 整合权限信息（角色权限去重）
5. 使用Redis缓存（5分钟过期）

---

### 3.2 用户列表查询

#### 需求描述
分页查询用户列表，支持多条件筛选和排序。

#### 接口名称
用户列表查询接口

#### 设计原因
- 管理员需要查看和管理所有用户
- 支持灵活的查询条件满足不同场景
- 分页设计避免大数据量查询

#### 请求类型
GET

#### 接口路径
`/users`

#### 接口参数
```typescript
// Query Parameters
{
  page?: number;         // 页码，默认1
  pageSize?: number;     // 每页数量，默认20，最大100
  keyword?: string;      // 搜索关键词（用户名/邮箱/手机号/昵称）
  status?: string;       // 用户状态
  roleId?: number;       // 角色ID
  organizationId?: number; // 组织ID
  tagId?: number;        // 标签ID
  startDate?: string;    // 注册开始时间
  endDate?: string;      // 注册结束时间
  sortBy?: string;       // 排序字段：createdAt,lastLoginAt
  sortOrder?: string;    // 排序方向：asc,desc
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "items": [
      {
        "id": 1234567890,
        "username": "john_doe",
        "email": "john@example.com",
        "mobile": "138****8000",
        "nickname": "John",
        "avatar": "https://...",
        "status": "active",
        "roles": ["admin", "user"],
        "organizations": ["技术部"],
        "tags": ["VIP"],
        "loginCount": 100,
        "lastLoginAt": "2024-01-01T12:00:00Z",
        "createdAt": "2023-01-01T00:00:00Z"
      }
    ],
    "pagination": {
      "page": 1,
      "pageSize": 20,
      "total": 100,
      "totalPages": 5
    }
  }
}
```

#### 开发思路
1. 参数验证和权限检查（需要user:read权限）
2. 构建查询条件：
   - 关键词模糊查询
   - 状态精确匹配
   - 关联表过滤（角色、组织、标签）
   - 时间范围查询
3. 执行分页查询（使用索引优化）
4. 批量查询关联信息（减少N+1查询）
5. 数据脱敏（手机号中间4位）

---

### 3.3 创建用户

#### 需求描述
管理员创建新用户，可直接设置角色、组织等信息。

#### 接口名称
创建用户接口

#### 设计原因
- 管理员需要批量创建用户
- 可预设用户角色和组织
- 支持直接激活状态

#### 请求类型
POST

#### 接口路径
`/users`

#### 接口参数
```typescript
{
  username: string;
  email: string;
  password: string;
  mobile?: string;
  nickname?: string;
  status?: string;      // 默认active
  gender?: number;
  birthday?: string;
  bio?: string;
  roleIds?: number[];   // 角色ID数组
  organizationIds?: Array<{
    id: number;
    isPrimary: boolean;
    position?: string;
  }>;                   // 组织信息
  tagIds?: number[];    // 标签ID数组
  sendNotification?: boolean; // 是否发送通知邮件
}
```

#### 开发思路
1. 权限检查（需要user:create权限）
2. 参数验证（唯一性检查）
3. 使用事务处理：
   - 创建用户记录
   - 分配角色
   - 分配组织
   - 分配标签
4. 发送通知邮件（可选）
5. 记录操作日志

---

### 3.4 更新用户信息

#### 需求描述
更新用户基本信息和关联信息。

#### 接口名称
更新用户信息接口

#### 设计原因
- 支持用户自主修改个人信息
- 管理员可修改用户所有信息
- 分离基本信息和关联信息更新

#### 请求类型
PUT

#### 接口路径
`/users/{userId}`

#### 接口参数
```typescript
{
  email?: string;
  mobile?: string;
  nickname?: string;
  avatar?: string;
  gender?: number;
  birthday?: string;
  bio?: string;
  // 以下字段需要管理员权限
  status?: string;
  roleIds?: number[];
  organizationIds?: Array<{
    id: number;
    isPrimary: boolean;
    position?: string;
  }>;
  tagIds?: number[];
}
```

#### 开发思路
1. 权限检查：
   - 用户可修改自己的基本信息
   - 管理员可修改所有信息
2. 参数验证（邮箱唯一性等）
3. 使用乐观锁防止并发冲突
4. 更新关联信息时先删后增
5. 清除相关缓存

---

### 3.5 重置密码

#### 需求描述
用户忘记密码时通过邮箱重置。

#### 接口名称
申请重置密码接口

#### 请求类型
POST

#### 接口路径
`/users/password/reset-request`

#### 接口参数
```typescript
{
  email: string;
  captcha: string;
  captchaId: string;
}
```

#### 开发思路
1. 验证邮箱存在
2. 生成重置token（6位数字或链接）
3. 存入Redis（30分钟过期）
4. 发送重置邮件
5. 限制发送频率（1分钟内不可重复）

---

## 4. 角色管理模块 (Role Management)

### 4.1 角色树查询

#### 需求描述
查询角色树形结构，支持权限继承展示。

#### 接口名称
角色树查询接口

#### 设计原因
- 角色具有层级关系需要树形展示
- 支持权限继承机制
- 便于理解角色体系

#### 请求类型
GET

#### 接口路径
`/roles/tree`

#### 接口参数
```typescript
{
  status?: string;      // 过滤状态
  withPermissions?: boolean; // 是否包含权限信息
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": [
    {
      "id": 1,
      "code": "super_admin",
      "name": "超级管理员",
      "description": "拥有所有权限",
      "status": "active",
      "isSystem": true,
      "permissionCount": 50,
      "children": [
        {
          "id": 2,
          "code": "admin",
          "name": "管理员",
          "pid": 1,
          "children": []
        }
      ]
    }
  ]
}
```

#### 开发思路
1. 查询所有角色（使用path字段优化）
2. 构建树形结构（递归或迭代）
3. 统计每个角色的权限数量
4. 使用Redis缓存（角色变更时失效）

---

### 4.2 创建角色

#### 需求描述
创建新角色并分配权限，支持角色继承。

#### 接口名称
创建角色接口

#### 设计原因
- 灵活的角色管理支持业务扩展
- 权限继承减少重复配置
- 下级角色权限不能超过上级

#### 请求类型
POST

#### 接口路径
`/roles`

#### 接口参数
```typescript
{
  code: string;         // 角色代码，唯一
  name: string;         // 角色名称
  description?: string; // 角色描述
  pid?: number;         // 父角色ID
  status?: string;      // 状态，默认active
  permissionIds: number[]; // 权限ID数组
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "创建成功",
  "data": {
    "id": 10,
    "code": "editor",
    "name": "编辑员",
    "path": "/1/2/10/",
    "level": 3
  }
}
```

#### 开发思路
1. 权限检查（需要role:create权限）
2. 验证角色代码唯一性
3. 验证父角色存在性
4. 检查权限分配合法性：
   - 获取父角色所有权限
   - 确保新角色权限是父角色权限的子集
5. 使用事务创建：
   - 创建角色记录
   - 计算并设置path和level
   - 分配权限
   - 生成权限快照
6. 清除角色缓存

---

### 4.3 更新角色权限

#### 需求描述
动态调整角色权限，支持批量操作。

#### 接口名称
更新角色权限接口

#### 设计原因
- 业务变化需要调整权限
- 支持灵活的权限管理
- 保证权限继承一致性

#### 请求类型
PUT

#### 接口路径
`/roles/{roleId}/permissions`

#### 接口参数
```typescript
{
  permissionIds: number[]; // 新的权限ID数组（全量）
}
```

#### 开发思路
1. 检查角色是否为系统角色
2. 验证权限合法性（不超过父角色）
3. 对比新旧权限，计算差异
4. 使用事务更新：
   - 删除旧权限关联
   - 创建新权限关联
   - 更新权限快照
5. 级联更新子角色（移除超出的权限）
6. 清除相关用户的权限缓存

---

## 5. 权限管理模块 (Permission Management)

### 5.1 权限树查询

#### 需求描述
查询权限树形结构，按类型分组展示。

#### 接口名称
权限树查询接口

#### 设计原因
- 权限具有层级关系（菜单-页面-按钮）
- 便于权限分配时的选择
- 支持不同类型权限的管理

#### 请求类型
GET

#### 接口路径
`/permissions/tree`

#### 接口参数
```typescript
{
  type?: string;        // 权限类型：menu,button,api,data
  status?: string;      // 状态过滤
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": [
    {
      "id": 1,
      "code": "system",
      "name": "系统管理",
      "type": "menu",
      "children": [
        {
          "id": 2,
          "code": "system:user",
          "name": "用户管理",
          "type": "menu",
          "children": [
            {
              "id": 3,
              "code": "user:read",
              "name": "查看用户",
              "type": "api",
              "resource": "user",
              "action": "read"
            }
          ]
        }
      ]
    }
  ]
}
```

#### 开发思路
1. 查询权限列表
2. 按类型分组
3. 构建树形结构
4. 使用Redis缓存

---

### 5.2 批量创建权限

#### 需求描述
支持批量导入权限配置。

#### 接口名称
批量创建权限接口

#### 设计原因
- 新模块上线需要批量添加权限
- 提高配置效率
- 支持权限模板导入

#### 请求类型
POST

#### 接口路径
`/permissions/batch`

#### 接口参数
```typescript
{
  permissions: Array<{
    code: string;
    name: string;
    type: string;
    resource?: string;
    action?: string;
    pid?: number;
    description?: string;
  }>
}
```

#### 开发思路
1. 批量验证权限代码唯一性
2. 验证父权限存在性
3. 使用事务批量插入
4. 清除权限缓存

---

## 6. 组织架构模块 (Organization Management)

### 6.1 组织树查询

#### 需求描述
查询组织架构树，支持人员统计。

#### 接口名称
组织架构树查询接口

#### 设计原因
- 直观展示组织层级关系
- 便于用户分配和管理
- 支持组织人员统计

#### 请求类型
GET

#### 接口路径
`/organizations/tree`

#### 接口参数
```typescript
{
  type?: string;        // 组织类型
  status?: string;      // 状态
  withStats?: boolean;  // 是否包含统计信息
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": [
    {
      "id": 1,
      "code": "ROOT",
      "name": "星撰集团",
      "type": "company",
      "userCount": 100,
      "children": [
        {
          "id": 2,
          "code": "TECH",
          "name": "技术部",
          "type": "department",
          "userCount": 30,
          "leader": {
            "id": 123,
            "name": "张三"
          },
          "children": []
        }
      ]
    }
  ]
}
```

#### 开发思路
1. 查询组织列表
2. 构建树形结构
3. 如需统计：
   - 批量查询用户组织关联
   - 聚合统计各组织人数
4. 查询负责人信息
5. 使用Redis缓存

---

### 6.2 调整组织架构

#### 需求描述
支持拖拽调整组织层级关系。

#### 接口名称
调整组织架构接口

#### 设计原因
- 组织架构会随业务发展调整
- 支持灵活的组织变更
- 保持数据完整性

#### 请求类型
PUT

#### 接口路径
`/organizations/{organizationId}/move`

#### 接口参数
```typescript
{
  targetPid: number;    // 目标父组织ID
  targetIndex?: number; // 目标位置索引
}
```

#### 开发思路
1. 验证目标组织存在性
2. 检查是否会形成循环
3. 使用事务更新：
   - 更新pid
   - 重新计算path和level
   - 更新所有子组织的path
   - 调整排序
4. 记录组织变更日志

---

## 7. 字典管理模块 (Dictionary Management)

### 7.1 字典类型树查询

#### 需求描述
查询字典类型的树形结构，支持分类管理。

#### 接口名称
字典类型树查询接口

#### 设计原因
- 字典类型支持分类管理
- 便于字典的组织和查找
- 区分系统字典和业务字典

#### 请求类型
GET

#### 接口路径
`/dictionaries/types/tree`

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": [
    {
      "id": 1,
      "code": "system",
      "name": "系统字典",
      "isSystem": true,
      "children": [
        {
          "id": 10,
          "code": "user_status",
          "name": "用户状态",
          "itemCount": 4
        }
      ]
    }
  ]
}
```

---

### 7.2 获取字典项

#### 需求描述
根据字典类型获取所有字典项，支持树形字典。

#### 接口名称
获取字典项接口

#### 设计原因
- 前端下拉框等组件需要字典数据
- 支持动态配置
- 减少硬编码

#### 请求类型
GET

#### 接口路径
`/dictionaries/items`

#### 接口参数
```typescript
{
  typeCode: string;     // 字典类型代码
  tree?: boolean;       // 是否返回树形结构
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": [
    {
      "key": "active",
      "value": "active",
      "label": "正常",
      "color": "#52c41a",
      "sortOrder": 1
    }
  ]
}
```

#### 开发思路
1. 根据typeCode查询字典类型
2. 查询该类型下的所有字典项
3. 如果是树形字典，构建树结构
4. 使用Redis缓存（字典变更少）

---

### 7.3 批量更新字典项

#### 需求描述
支持批量更新字典项，保持顺序。

#### 接口名称
批量更新字典项接口

#### 设计原因
- 字典项通常需要批量维护
- 保持显示顺序的一致性
- 提高维护效率

#### 请求类型
PUT

#### 接口路径
`/dictionaries/types/{typeId}/items/batch`

#### 接口参数
```typescript
{
  items: Array<{
    id?: number;        // 有ID为更新，无ID为新增
    key: string;
    value: string;
    label: string;
    labelEn?: string;
    pid?: number;
    sortOrder: number;
    status?: string;
    color?: string;
    extra?: object;
  }>
}
```

#### 开发思路
1. 验证字典类型存在
2. 检查是否为系统字典
3. 验证key在类型内唯一
4. 使用事务处理：
   - 标记删除不在列表中的项
   - 更新已存在的项
   - 创建新项
5. 清除字典缓存

---

## 8. 标签管理模块 (Tag Management)

### 8.1 标签列表查询

#### 需求描述
查询标签列表，支持按类型和使用频率排序。

#### 接口名称
标签列表查询接口

#### 设计原因
- 便于标签的统一管理
- 支持热门标签展示
- 不同类型标签分开管理

#### 请求类型
GET

#### 接口路径
`/tags`

#### 接口参数
```typescript
{
  type?: string;        // 标签类型
  keyword?: string;     // 搜索关键词
  sortBy?: string;      // 排序：usageCount,createdAt
  page?: number;
  pageSize?: number;
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "items": [
      {
        "id": 1,
        "name": "VIP",
        "type": "user",
        "color": "#ff4d4f",
        "usageCount": 100,
        "description": "VIP用户"
      }
    ],
    "pagination": {
      "page": 1,
      "pageSize": 20,
      "total": 50
    }
  }
}
```

---

### 8.2 标签智能推荐

#### 需求描述
根据用户特征智能推荐标签。

#### 接口名称
标签推荐接口

#### 设计原因
- 提高标签使用的准确性
- 基于规则引擎自动打标
- 减少人工维护成本

#### 请求类型
POST

#### 接口路径
`/tags/recommend`

#### 接口参数
```typescript
{
  userId: number;
  type: string;         // 推荐类型
}
```

#### 开发思路
1. 获取用户特征数据
2. 执行推荐规则：
   - 活跃度规则（登录次数、最后登录时间）
   - 贡献度规则（内容创作数量）
   - 消费规则（VIP等级）
3. 返回推荐标签列表
4. 记录推荐日志

---

## 9. 通用功能接口

### 9.1 图形验证码

#### 需求描述
生成图形验证码，用于注册、登录等场景。

#### 接口名称
获取图形验证码接口

#### 请求类型
GET

#### 接口路径
`/captcha`

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "captchaId": "xxxx-xxxx-xxxx",
    "captchaImage": "data:image/svg+xml;base64,..."
  }
}
```

---

### 9.2 文件上传

#### 需求描述
通用文件上传接口，支持头像等文件上传。

#### 接口名称
文件上传接口

#### 请求类型
POST

#### 接口路径
`/upload`

#### 请求格式
multipart/form-data

#### 接口参数
```typescript
{
  file: File;           // 文件
  type: string;         // 文件类型：avatar,document
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "上传成功",
  "data": {
    "url": "https://oss.starzh.com/xxx.jpg",
    "size": 102400,
    "name": "avatar.jpg"
  }
}
```

---

## 10. 安全性设计

### 10.1 认证机制
- JWT Token认证
- Token有效期2小时
- RefreshToken有效期7天
- 支持Token黑名单

### 10.2 权限控制
- 基于RBAC的权限模型
- 接口级别的权限控制
- 数据级别的权限过滤

### 10.3 安全措施
- 所有接口HTTPS加密传输
- 敏感操作二次验证
- SQL注入防护（参数化查询）
- XSS防护（输入过滤）
- CSRF防护（Token验证）
- 请求频率限制
- IP黑白名单

### 10.4 日志审计
- 完整的操作日志
- 敏感操作告警
- 异常行为检测

---

## 11. 性能优化

### 11.1 缓存策略
- Redis缓存用户信息（5分钟）
- 角色权限缓存（变更时失效）
- 字典数据缓存（1小时）
- HTTP缓存头优化

### 11.2 查询优化
- 合理使用数据库索引
- 避免N+1查询问题
- 大数据量分页查询
- 异步处理耗时操作

### 11.3 并发控制
- 接口限流（令牌桶）
- 数据库连接池
- 异步任务队列
- 乐观锁防止超卖

---

## 12. 错误处理

### 12.1 错误码规范

| 错误码 | HTTP状态码 | 说明 |
|--------|------------|------|
| 0 | 200 | 成功 |
| 40001 | 400 | 参数错误 |
| 40002 | 400 | 参数格式错误 |
| 40003 | 400 | 参数超出范围 |
| 40101 | 401 | 未登录 |
| 40102 | 401 | Token过期 |
| 40103 | 401 | Token无效 |
| 40301 | 403 | 无权限 |
| 40302 | 403 | 账号被禁用 |
| 40401 | 404 | 资源不存在 |
| 40901 | 409 | 资源已存在 |
| 42301 | 423 | 账号被锁定 |
| 50001 | 500 | 服务器内部错误 |
| 50002 | 500 | 数据库错误 |
| 50003 | 503 | 服务不可用 |

### 12.2 错误响应示例
```json
{
  "code": 40001,
  "message": "用户名不能为空",
  "data": {
    "field": "username",
    "value": null
  },
  "timestamp": 1640995200000,
  "requestId": "xxxx-xxxx-xxxx"
}
```

---

## 13. 接口版本管理

### 13.1 版本策略
- URL路径版本化：/v1, /v2
- 向后兼容原则
- 废弃接口提前通知
- 版本迁移指南

### 13.2 版本示例
```
/v1/users (当前版本)
/v2/users (新版本，结构优化)
```

---

## 14. 开发规范总结

### 14.1 命名规范
- RESTful资源命名使用复数
- 路径使用小写字母和连字符
- 查询参数使用驼峰命名

### 14.2 状态码使用
- 200: 成功
- 201: 创建成功
- 204: 无内容（删除成功）
- 400: 客户端错误
- 401: 未认证
- 403: 无权限
- 404: 资源不存在
- 409: 资源冲突
- 500: 服务器错误

### 14.3 最佳实践
- 幂等性设计（PUT/DELETE）
- 分页查询限制最大条数
- 敏感数据脱敏
- 异步处理耗时操作
- 合理的缓存策略
- 完善的错误处理
- 详细的日志记录
```

```markdown
# M2 - 基础用户系统 - 详细接口设计

## 1. 概述

本文档基于M2阶段的数据库设计和产品需求，提供完整的RESTful API接口设计方案。所有接口遵循以下原则：

- **RESTful规范**：使用标准HTTP方法和状态码
- **统一响应格式**：所有接口返回统一的JSON格式
- **安全性**：JWT认证、权限控制、数据验证
- **高性能**：合理的缓存策略、分页设计
- **版本控制**：API版本化管理

### 基础URL
```
https://api.starzh.com/v1
```

### 统一响应格式
```json
{
  "code": 0,          // 业务状态码，0表示成功
  "message": "success", // 提示信息
  "data": {},         // 响应数据
  "timestamp": 1640995200000, // 时间戳
  "requestId": "xxxx-xxxx-xxxx" // 请求ID，用于追踪
}
```

### 统一错误码规范
- 0: 成功
- 400xx: 客户端错误（参数错误、验证失败等）
- 401xx: 认证错误
- 403xx: 权限错误
- 404xx: 资源不存在
- 409xx: 资源冲突
- 500xx: 服务器错误

---

## 2. 认证模块 (Authentication)

### 2.1 用户注册

#### 需求描述
允许新用户通过邮箱注册账号，需要邮箱验证激活。支持基本的用户名、密码规则校验。

#### 接口名称
用户注册接口

#### 设计原因
- 提供用户自主注册功能
- 通过邮箱验证确保用户真实性
- 防止恶意注册和垃圾账号

#### 请求类型
POST

#### 接口路径
`/auth/register`

#### 接口参数
```typescript
{
  username: string;     // 用户名，3-50字符，字母开头，仅包含字母数字下划线
  email: string;        // 邮箱地址，需符合邮箱格式
  password: string;     // 密码，8-100字符，必须包含大小写字母和数字
  confirmPassword: string; // 确认密码，需与password一致
  captcha: string;      // 图形验证码
  captchaId: string;    // 验证码ID
}
```

**参数约束原因**：
- username: 限制长度和字符类型，防止特殊字符引起的安全问题
- password: 强密码策略，提高账户安全性
- captcha: 防止机器人批量注册

#### 响应分类
- 成功：201 Created - 注册成功，发送激活邮件
- 失败：
  - 400 Bad Request - 参数验证失败
  - 409 Conflict - 用户名或邮箱已存在

#### 响应格式
```json
// 成功响应
{
  "code": 0,
  "message": "注册成功，请查收邮件激活账号",
  "data": {
    "userId": 1234567890,
    "username": "john_doe",
    "email": "john@example.com",
    "status": "inactive"
  }
}

// 失败响应示例
{
  "code": 40901,
  "message": "用户名已被占用",
  "data": null
}
```

#### 开发思路
1. 参数验证层：使用Elysia的t验证器进行参数校验
2. 业务逻辑层：
   - 验证图形验证码
   - 检查用户名和邮箱唯一性
   - 密码使用bcrypt加密（成本因子12）
   - 生成用户记录（状态为inactive）
   - 生成激活token并存入Redis（24小时过期）
   - 发送激活邮件（异步队列）
3. 数据访问层：使用事务确保数据一致性
4. 日志记录：记录注册操作到sys_operation_logs

---

### 2.2 用户登录

#### 需求描述
支持用户名或邮箱登录，实现登录失败次数限制，防止暴力破解。

#### 接口名称
用户登录接口

#### 设计原因
- 提供安全的身份认证机制
- 支持多种登录方式提升用户体验
- 防止暴力破解攻击

#### 请求类型
POST

#### 接口路径
`/auth/login`

#### 接口参数
```typescript
{
  account: string;      // 用户名或邮箱
  password: string;     // 密码
  captcha?: string;     // 验证码（连续失败3次后必填）
  captchaId?: string;   // 验证码ID
  rememberMe?: boolean; // 记住我，默认false
}
```

#### 响应分类
- 成功：200 OK - 登录成功，返回token
- 失败：
  - 401 Unauthorized - 用户名或密码错误
  - 423 Locked - 账号被锁定

#### 响应格式
```json
// 成功响应
{
  "code": 0,
  "message": "登录成功",
  "data": {
    "token": "eyJhbGciOiJIUzI1NiIs...",
    "refreshToken": "xxxx-xxxx-xxxx",
    "expiresIn": 7200,
    "user": {
      "id": 1234567890,
      "username": "john_doe",
      "nickname": "John",
      "avatar": "https://...",
      "roles": ["user"]
    }
  }
}
```

#### 开发思路
1. 查询用户（支持username或email）
2. 检查账号状态和锁定状态
3. 验证密码
4. 处理登录失败：
   - 增加失败次数
   - 超过5次锁定30分钟
   - 3次失败后要求验证码
5. 登录成功：
   - 清除失败次数
   - 生成JWT token
   - 更新最后登录信息
   - 记录登录日志

---

### 2.3 刷新Token

#### 需求描述
使用refreshToken换取新的accessToken，实现无感续期。

#### 接口名称
Token刷新接口

#### 设计原因
- 短期accessToken + 长期refreshToken模式
- 提高安全性，减少token泄露风险
- 实现用户无感续期体验

#### 请求类型
POST

#### 接口路径
`/auth/refresh`

#### 接口参数
```typescript
{
  refreshToken: string; // 刷新令牌
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "刷新成功",
  "data": {
    "token": "new-access-token",
    "expiresIn": 7200
  }
}
```

#### 开发思路
1. 验证refreshToken有效性
2. 检查用户状态
3. 生成新的accessToken
4. 可选：轮转refreshToken
5. 记录刷新日志

---

### 2.4 账号激活

#### 需求描述
用户通过邮件中的链接或验证码激活账号。

#### 接口名称
账号激活接口

#### 设计原因
- 验证邮箱真实性
- 防止垃圾注册
- 提高用户质量

#### 请求类型
POST

#### 接口路径
`/auth/activate`

#### 接口参数
```typescript
{
  token: string;        // 激活令牌（从邮件链接获取）
  // 或
  email: string;        // 邮箱
  code: string;         // 6位数字激活码
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "账号激活成功",
  "data": {
    "userId": 1234567890,
    "username": "john_doe",
    "status": "active"
  }
}
```

#### 开发思路
1. 验证激活token或激活码
2. 检查是否过期
3. 更新用户状态为active
4. 删除Redis中的激活信息
5. 发送欢迎邮件
6. 记录激活日志

---

### 2.5 退出登录

#### 需求描述
用户主动退出登录，清除token。

#### 接口名称
退出登录接口

#### 设计原因
- 用户主动结束会话
- 清除服务端缓存
- 增强安全性

#### 请求类型
POST

#### 接口路径
`/auth/logout`

#### 请求头
```
Authorization: Bearer <token>
```

#### 响应格式
```json
{
  "code": 0,
  "message": "退出成功",
  "data": null
}
```

#### 开发思路
1. 获取当前token
2. 加入token黑名单（Redis）
3. 清除用户相关缓存
4. 记录退出日志
```

```markdown
// ... existing code ...

## 3. 用户管理模块 (User Management)

### 3.1 获取当前用户信息

#### 需求描述
获取当前登录用户的详细信息，包括基本信息、角色、权限、组织等。

#### 接口名称
获取当前用户信息接口

#### 设计原因
- 前端需要用户信息进行界面渲染
- 权限控制需要用户角色和权限信息
- 统一的用户信息获取入口

#### 请求类型
GET

#### 接口路径
`/users/me`

#### 请求头
```
Authorization: Bearer <token>
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "id": 1234567890,
    "username": "john_doe",
    "email": "john@example.com",
    "mobile": "13800138000",
    "nickname": "John",
    "avatar": "https://...",
    "gender": 1,
    "birthday": "1990-01-01",
    "bio": "Hello world",
    "status": "active",
    "lastLoginAt": "2024-01-01T12:00:00Z",
    "roles": [
      {
        "id": 1,
        "code": "admin",
        "name": "管理员"
      }
    ],
    "permissions": [
      {
        "code": "user:read",
        "name": "查看用户",
        "type": "api"
      }
    ],
    "organizations": [
      {
        "id": 1,
        "name": "技术部",
        "isPrimary": true,
        "position": "工程师"
      }
    ],
    "tags": [
      {
        "id": 1,
        "name": "VIP",
        "color": "#ff4d4f"
      }
    ]
  }
}
```

#### 开发思路
1. 从JWT token中获取用户ID
2. 查询用户基本信息
3. 并行查询关联信息：
   - 用户角色（包含权限快照）
   - 用户组织
   - 用户标签
4. 整合权限信息（角色权限去重）
5. 使用Redis缓存（5分钟过期）

---

### 3.2 用户列表查询

#### 需求描述
分页查询用户列表，支持多条件筛选和排序。

#### 接口名称
用户列表查询接口

#### 设计原因
- 管理员需要查看和管理所有用户
- 支持灵活的查询条件满足不同场景
- 分页设计避免大数据量查询

#### 请求类型
GET

#### 接口路径
`/users`

#### 接口参数
```typescript
// Query Parameters
{
  page?: number;         // 页码，默认1
  pageSize?: number;     // 每页数量，默认20，最大100
  keyword?: string;      // 搜索关键词（用户名/邮箱/手机号/昵称）
  status?: string;       // 用户状态
  roleId?: number;       // 角色ID
  organizationId?: number; // 组织ID
  tagId?: number;        // 标签ID
  startDate?: string;    // 注册开始时间
  endDate?: string;      // 注册结束时间
  sortBy?: string;       // 排序字段：createdAt,lastLoginAt
  sortOrder?: string;    // 排序方向：asc,desc
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "items": [
      {
        "id": 1234567890,
        "username": "john_doe",
        "email": "john@example.com",
        "mobile": "138****8000",
        "nickname": "John",
        "avatar": "https://...",
        "status": "active",
        "roles": ["admin", "user"],
        "organizations": ["技术部"],
        "tags": ["VIP"],
        "loginCount": 100,
        "lastLoginAt": "2024-01-01T12:00:00Z",
        "createdAt": "2023-01-01T00:00:00Z"
      }
    ],
    "pagination": {
      "page": 1,
      "pageSize": 20,
      "total": 100,
      "totalPages": 5
    }
  }
}
```

#### 开发思路
1. 参数验证和权限检查（需要user:read权限）
2. 构建查询条件：
   - 关键词模糊查询
   - 状态精确匹配
   - 关联表过滤（角色、组织、标签）
   - 时间范围查询
3. 执行分页查询（使用索引优化）
4. 批量查询关联信息（减少N+1查询）
5. 数据脱敏（手机号中间4位）

---

### 3.3 创建用户

#### 需求描述
管理员创建新用户，可直接设置角色、组织等信息。

#### 接口名称
创建用户接口

#### 设计原因
- 管理员需要批量创建用户
- 可预设用户角色和组织
- 支持直接激活状态

#### 请求类型
POST

#### 接口路径
`/users`

#### 接口参数
```typescript
{
  username: string;
  email: string;
  password: string;
  mobile?: string;
  nickname?: string;
  status?: string;      // 默认active
  gender?: number;
  birthday?: string;
  bio?: string;
  roleIds?: number[];   // 角色ID数组
  organizationIds?: Array<{
    id: number;
    isPrimary: boolean;
    position?: string;
  }>;                   // 组织信息
  tagIds?: number[];    // 标签ID数组
  sendNotification?: boolean; // 是否发送通知邮件
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "创建成功",
  "data": {
    "id": 1234567890,
    "username": "new_user",
    "email": "new@example.com",
    "status": "active"
  }
}
```

#### 开发思路
1. 权限检查（需要user:create权限）
2. 参数验证（唯一性检查）
3. 使用事务处理：
   - 创建用户记录
   - 分配角色
   - 分配组织
   - 分配标签
4. 发送通知邮件（可选）
5. 记录操作日志

---

### 3.4 更新用户信息

#### 需求描述
更新用户基本信息和关联信息。

#### 接口名称
更新用户信息接口

#### 设计原因
- 支持用户自主修改个人信息
- 管理员可修改用户所有信息
- 分离基本信息和关联信息更新

#### 请求类型
PUT

#### 接口路径
`/users/{userId}`

#### 接口参数
```typescript
{
  email?: string;
  mobile?: string;
  nickname?: string;
  avatar?: string;
  gender?: number;
  birthday?: string;
  bio?: string;
  // 以下字段需要管理员权限
  status?: string;
  roleIds?: number[];
  organizationIds?: Array<{
    id: number;
    isPrimary: boolean;
    position?: string;
  }>;
  tagIds?: number[];
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "更新成功",
  "data": {
    "id": 1234567890,
    "username": "john_doe",
    "email": "john@example.com",
    "updatedAt": "2024-01-01T12:00:00Z"
  }
}
```

#### 开发思路
1. 权限检查：
   - 用户可修改自己的基本信息
   - 管理员可修改所有信息
   - root用户信息限制修改
2. 参数验证（邮箱唯一性等）
3. 使用乐观锁防止并发冲突
4. 更新关联信息时先删后增
5. 清除相关缓存

---

### 3.5 修改密码

#### 需求描述
用户修改自己的密码，需要验证原密码。

#### 接口名称
修改密码接口

#### 设计原因
- 用户自主管理密码
- 增强账户安全性
- 防止未授权修改

#### 请求类型
PUT

#### 接口路径
`/users/me/password`

#### 接口参数
```typescript
{
  oldPassword: string;  // 原密码
  newPassword: string;  // 新密码
  confirmPassword: string; // 确认新密码
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "密码修改成功",
  "data": null
}
```

#### 开发思路
1. 验证原密码正确性
2. 验证新密码符合规则
3. 更新密码（bcrypt加密）
4. 清除所有该用户的token
5. 发送密码修改通知邮件

---

### 3.6 重置密码

#### 需求描述
用户忘记密码时通过邮箱重置。

#### 接口名称
申请重置密码接口

#### 设计原因
- 用户忘记密码的补救措施
- 通过邮箱验证身份
- 防止恶意重置

#### 请求类型
POST

#### 接口路径
`/users/password/reset-request`

#### 接口参数
```typescript
{
  email: string;
  captcha: string;
  captchaId: string;
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "重置邮件已发送",
  "data": null
}
```

#### 开发思路
1. 验证邮箱存在
2. 验证图形验证码
3. 生成重置token（6位数字或链接）
4. 存入Redis（30分钟过期）
5. 发送重置邮件
6. 限制发送频率（1分钟内不可重复）

---

### 3.7 确认重置密码

#### 需求描述
使用重置token设置新密码。

#### 接口名称
确认重置密码接口

#### 请求类型
POST

#### 接口路径
`/users/password/reset-confirm`

#### 接口参数
```typescript
{
  token: string;        // 重置token
  email: string;        // 邮箱
  newPassword: string;  // 新密码
  confirmPassword: string; // 确认密码
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "密码重置成功",
  "data": null
}
```

#### 开发思路
1. 验证token有效性和匹配性
2. 验证新密码规则
3. 更新用户密码
4. 删除重置token
5. 清除用户所有token
6. 发送重置成功通知

---

### 3.8 删除用户

#### 需求描述
软删除用户，保留数据用于审计。

#### 接口名称
删除用户接口

#### 设计原因
- 满足用户注销需求
- 保留数据用于审计
- 支持误删恢复

#### 请求类型
DELETE

#### 接口路径
`/users/{userId}`

#### 响应格式
```json
{
  "code": 0,
  "message": "删除成功",
  "data": null
}
```

#### 开发思路
1. 权限检查（需要user:delete权限）
2. 检查是否为root用户（禁止删除）
3. 检查是否为自己（需要二次确认）
4. 更新deleted_at字段
5. 清除用户所有会话
6. 记录删除操作日志

---

### 3.9 批量操作用户

#### 需求描述
批量启用、禁用、删除用户。

#### 接口名称
批量操作用户接口

#### 设计原因
- 提高管理效率
- 支持批量处理
- 减少重复操作

#### 请求类型
POST

#### 接口路径
`/users/batch`

#### 接口参数
```typescript
{
  userIds: number[];    // 用户ID数组
  action: string;       // 操作类型：enable,disable,delete
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "操作成功",
  "data": {
    "success": 10,
    "failed": 0,
    "errors": []
  }
}
```

#### 开发思路
1. 权限检查
2. 过滤掉root用户
3. 批量执行操作
4. 记录操作结果
5. 返回执行统计
```

```markdown
// ... existing code ...

## 4. 角色管理模块 (Role Management)

### 4.1 角色树查询

#### 需求描述
查询角色树形结构，支持权限继承展示。

#### 接口名称
角色树查询接口

#### 设计原因
- 角色具有层级关系需要树形展示
- 支持权限继承机制
- 便于理解角色体系

#### 请求类型
GET

#### 接口路径
`/roles/tree`

#### 接口参数
```typescript
{
  status?: string;      // 过滤状态
  withPermissions?: boolean; // 是否包含权限信息
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": [
    {
      "id": 1,
      "code": "super_admin",
      "name": "超级管理员",
      "description": "拥有所有权限",
      "status": "active",
      "isSystem": true,
      "permissionCount": 50,
      "children": [
        {
          "id": 2,
          "code": "admin",
          "name": "管理员",
          "pid": 1,
          "children": []
        }
      ]
    }
  ]
}
```

#### 开发思路
1. 查询所有角色（使用path字段优化）
2. 构建树形结构（递归或迭代）
3. 统计每个角色的权限数量
4. 使用Redis缓存（角色变更时失效）

---

### 4.2 创建角色

#### 需求描述
创建新角色并分配权限，支持角色继承。

#### 接口名称
创建角色接口

#### 设计原因
- 灵活的角色管理支持业务扩展
- 权限继承减少重复配置
- 下级角色权限不能超过上级

#### 请求类型
POST

#### 接口路径
`/roles`

#### 接口参数
```typescript
{
  code: string;         // 角色代码，唯一
  name: string;         // 角色名称
  description?: string; // 角色描述
  pid?: number;         // 父角色ID
  status?: string;      // 状态，默认active
  permissionIds: number[]; // 权限ID数组
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "创建成功",
  "data": {
    "id": 10,
    "code": "editor",
    "name": "编辑员",
    "path": "/1/2/10/",
    "level": 3
  }
}
```

#### 开发思路
1. 权限检查（需要role:create权限）
2. 验证角色代码唯一性
3. 验证父角色存在性
4. 检查权限分配合法性：
   - 获取父角色所有权限
   - 确保新角色权限是父角色权限的子集
5. 使用事务创建：
   - 创建角色记录
   - 计算并设置path和level
   - 分配权限
   - 生成权限快照
6. 清除角色缓存

---

### 4.3 更新角色信息

#### 需求描述
更新角色基本信息，不包括权限。

#### 接口名称
更新角色信息接口

#### 设计原因
- 角色信息可能需要调整
- 分离基本信息和权限更新
- 防止误操作

#### 请求类型
PUT

#### 接口路径
`/roles/{roleId}`

#### 接口参数
```typescript
{
  name?: string;
  description?: string;
  status?: string;
  sortOrder?: number;
}
```

#### 开发思路
1. 权限检查（需要role:update权限）
2. 检查是否为系统角色（限制修改）
3. 更新角色信息
4. 清除角色缓存

---

### 4.4 更新角色权限

#### 需求描述
动态调整角色权限，支持批量操作。

#### 接口名称
更新角色权限接口

#### 设计原因
- 业务变化需要调整权限
- 支持灵活的权限管理
- 保证权限继承一致性

#### 请求类型
PUT

#### 接口路径
`/roles/{roleId}/permissions`

#### 接口参数
```typescript
{
  permissionIds: number[]; // 新的权限ID数组（全量）
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "权限更新成功",
  "data": {
    "roleId": 10,
    "permissionCount": 20,
    "addedCount": 5,
    "removedCount": 3
  }
}
```

#### 开发思路
1. 检查角色是否为系统角色
2. 验证权限合法性（不超过父角色）
3. 对比新旧权限，计算差异
4. 使用事务更新：
   - 删除旧权限关联
   - 创建新权限关联
   - 更新权限快照
5. 级联更新子角色（移除超出的权限）
6. 清除相关用户的权限缓存

---

### 4.5 删除角色

#### 需求描述
删除角色，处理关联关系。

#### 接口名称
删除角色接口

#### 设计原因
- 清理无用角色
- 保持系统整洁
- 防止权限泄露

#### 请求类型
DELETE

#### 接口路径
`/roles/{roleId}`

#### 开发思路
1. 权限检查（需要role:delete权限）
2. 检查是否为系统角色（禁止删除）
3. 检查是否有用户使用该角色
4. 检查是否有子角色
5. 软删除角色
6. 清除相关缓存

---

### 4.6 角色用户查询

#### 需求描述
查询某个角色下的所有用户。

#### 接口名称
角色用户查询接口

#### 设计原因
- 了解角色使用情况
- 便于角色管理
- 支持用户迁移

#### 请求类型
GET

#### 接口路径
`/roles/{roleId}/users`

#### 接口参数
```typescript
{
  page?: number;
  pageSize?: number;
  keyword?: string;
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "items": [
      {
        "id": 123,
        "username": "john_doe",
        "email": "john@example.com",
        "assignedAt": "2024-01-01T00:00:00Z"
      }
    ],
    "pagination": {
      "page": 1,
      "pageSize": 20,
      "total": 50
    }
  }
}
```

---

## 5. 权限管理模块 (Permission Management)

### 5.1 权限树查询

#### 需求描述
查询权限树形结构，按类型分组展示。

#### 接口名称
权限树查询接口

#### 设计原因
- 权限具有层级关系（菜单-页面-按钮）
- 便于权限分配时的选择
- 支持不同类型权限的管理

#### 请求类型
GET

#### 接口路径
`/permissions/tree`

#### 接口参数
```typescript
{
  type?: string;        // 权限类型：menu,button,api,data
  status?: string;      // 状态过滤
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": [
    {
      "id": 1,
      "code": "system",
      "name": "系统管理",
      "type": "menu",
      "children": [
        {
          "id": 2,
          "code": "system:user",
          "name": "用户管理",
          "type": "menu",
          "children": [
            {
              "id": 3,
              "code": "user:read",
              "name": "查看用户",
              "type": "api",
              "resource": "user",
              "action": "read"
            }
          ]
        }
      ]
    }
  ]
}
```

#### 开发思路
1. 查询权限列表
2. 按类型分组
3. 构建树形结构
4. 使用Redis缓存

---

### 5.2 创建权限

#### 需求描述
创建新的权限节点。

#### 接口名称
创建权限接口

#### 设计原因
- 新功能需要新权限
- 灵活的权限扩展
- 支持细粒度控制

#### 请求类型
POST

#### 接口路径
`/permissions`

#### 接口参数
```typescript
{
  code: string;         // 权限代码
  name: string;         // 权限名称
  type: string;         // 权限类型
  resource?: string;    // 资源标识
  action?: string;      // 操作标识
  pid?: number;         // 父权限ID
  description?: string; // 描述
  meta?: object;        // 元数据（如图标、路由）
}
```

#### 开发思路
1. 权限检查（需要permission:create权限）
2. 验证权限代码唯一性
3. 验证父权限存在性
4. 创建权限记录
5. 清除权限缓存

---

### 5.3 批量创建权限

#### 需求描述
支持批量导入权限配置。

#### 接口名称
批量创建权限接口

#### 设计原因
- 新模块上线需要批量添加权限
- 提高配置效率
- 支持权限模板导入

#### 请求类型
POST

#### 接口路径
`/permissions/batch`

#### 接口参数
```typescript
{
  permissions: Array<{
    code: string;
    name: string;
    type: string;
    resource?: string;
    action?: string;
    pid?: number;
    description?: string;
  }>
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "批量创建成功",
  "data": {
    "success": 10,
    "failed": 0,
    "errors": []
  }
}
```

#### 开发思路
1. 批量验证权限代码唯一性
2. 验证父权限存在性
3. 使用事务批量插入
4. 返回执行结果统计
5. 清除权限缓存

---

### 5.4 更新权限

#### 需求描述
更新权限信息。

#### 接口名称
更新权限接口

#### 设计原因
- 权限名称或描述可能需要调整
- 元数据更新（如菜单图标）
- 状态变更

#### 请求类型
PUT

#### 接口路径
`/permissions/{permissionId}`

#### 接口参数
```typescript
{
  name?: string;
  description?: string;
  status?: string;
  meta?: object;
  sortOrder?: number;
}
```

#### 开发思路
1. 权限检查
2. 更新权限信息
3. 清除权限缓存
4. 通知相关角色缓存更新

---

### 5.5 删除权限

#### 需求描述
删除权限节点及其子权限。

#### 接口名称
删除权限接口

#### 设计原因
- 功能下线需要删除权限
- 保持权限体系整洁
- 防止权限泄露

#### 请求类型
DELETE

#### 接口路径
`/permissions/{permissionId}`

#### 开发思路
1. 权限检查（需要permission:delete权限）
2. 检查是否有角色使用该权限
3. 递归删除子权限
4. 清除相关缓存

---

### 5.6 权限检查接口

#### 需求描述
检查当前用户是否拥有特定权限。

#### 接口名称
权限检查接口

#### 设计原因
- 前端动态控制界面元素
- 细粒度的功能控制
- 实时权限验证

#### 请求类型
POST

#### 接口路径
`/permissions/check`

#### 接口参数
```typescript
{
  permissions: string[]; // 权限代码数组
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "user:read": true,
    "user:create": true,
    "user:delete": false
  }
}
```

#### 开发思路
1. 获取当前用户所有权限
2. 批量检查请求的权限
3. 返回权限检查结果
```

```markdown
// ... existing code ...

## 6. 组织架构模块 (Organization Management)

### 6.1 组织树查询

#### 需求描述
查询组织架构树，支持人员统计。

#### 接口名称
组织架构树查询接口

#### 设计原因
- 直观展示组织层级关系
- 便于用户分配和管理
- 支持组织人员统计

#### 请求类型
GET

#### 接口路径
`/organizations/tree`

#### 接口参数
```typescript
{
  type?: string;        // 组织类型
  status?: string;      // 状态
  withStats?: boolean;  // 是否包含统计信息
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": [
    {
      "id": 1,
      "code": "ROOT",
      "name": "星撰集团",
      "type": "company",
      "userCount": 100,
      "children": [
        {
          "id": 2,
          "code": "TECH",
          "name": "技术部",
          "type": "department",
          "userCount": 30,
          "leader": {
            "id": 123,
            "name": "张三"
          },
          "children": []
        }
      ]
    }
  ]
}
```

#### 开发思路
1. 查询组织列表
2. 构建树形结构
3. 如需统计：
   - 批量查询用户组织关联
   - 聚合统计各组织人数
4. 查询负责人信息
5. 使用Redis缓存

---

### 6.2 创建组织

#### 需求描述
创建新的组织节点。

#### 接口名称
创建组织接口

#### 设计原因
- 组织架构需要动态调整
- 支持业务扩展
- 灵活的组织管理

#### 请求类型
POST

#### 接口路径
`/organizations`

#### 接口参数
```typescript
{
  code: string;         // 组织代码
  name: string;         // 组织名称
  fullName?: string;    // 组织全称
  type: string;         // 组织类型
  pid?: number;         // 父组织ID
  leaderId?: number;    // 负责人ID
  address?: string;     // 地址
  phone?: string;       // 电话
  description?: string; // 描述
}
```

#### 开发思路
1. 权限检查（需要organization:create权限）
2. 验证组织代码唯一性
3. 验证父组织存在性
4. 创建组织记录
5. 计算path和level
6. 清除组织缓存

---

### 6.3 调整组织架构

#### 需求描述
支持拖拽调整组织层级关系。

#### 接口名称
调整组织架构接口

#### 设计原因
- 组织架构会随业务发展调整
- 支持灵活的组织变更
- 保持数据完整性

#### 请求类型
PUT

#### 接口路径
`/organizations/{organizationId}/move`

#### 接口参数
```typescript
{
  targetPid: number;    // 目标父组织ID
  targetIndex?: number; // 目标位置索引
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "调整成功",
  "data": {
    "id": 10,
    "oldPath": "/1/2/10/",
    "newPath": "/1/3/10/",
    "affectedCount": 5
  }
}
```

#### 开发思路
1. 验证目标组织存在性
2. 检查是否会形成循环
3. 使用事务更新：
   - 更新pid
   - 重新计算path和level
   - 更新所有子组织的path
   - 调整排序
4. 记录组织变更日志
5. 清除相关缓存

---

### 6.4 组织人员管理

#### 需求描述
管理组织内的人员分配。

#### 接口名称
组织人员分配接口

#### 设计原因
- 灵活的人员调动
- 支持批量操作
- 记录调动历史

#### 请求类型
POST

#### 接口路径
`/organizations/{organizationId}/users`

#### 接口参数
```typescript
{
  action: string;       // 操作：add,remove,move
  userIds: number[];    // 用户ID数组
  position?: string;    // 职位（添加时使用）
  isPrimary?: boolean;  // 是否主组织
  targetOrgId?: number; // 目标组织ID（移动时使用）
}
```

#### 开发思路
1. 权限检查
2. 验证用户和组织存在性
3. 执行批量操作：
   - add: 添加用户到组织
   - remove: 从组织移除用户
   - move: 移动到其他组织
4. 记录人员变动日志

---

### 6.5 删除组织

#### 需求描述
删除组织节点，处理人员安置。

#### 接口名称
删除组织接口

#### 设计原因
- 组织调整需要删除节点
- 确保人员妥善安置
- 保持数据完整性

#### 请求类型
DELETE

#### 接口路径
`/organizations/{organizationId}`

#### 接口参数
```typescript
{
  handleUsers?: string; // 人员处理方式：moveToParent,remove
  targetOrgId?: number; // 目标组织ID（自定义迁移时使用）
}
```

#### 开发思路
1. 权限检查（需要organization:delete权限）
2. 检查是否有子组织
3. 处理组织内人员
4. 软删除组织
5. 清除相关缓存

---

## 7. 字典管理模块 (Dictionary Management)

### 7.1 字典类型树查询

#### 需求描述
查询字典类型的树形结构，支持分类管理。

#### 接口名称
字典类型树查询接口

#### 设计原因
- 字典类型支持分类管理
- 便于字典的组织和查找
- 区分系统字典和业务字典

#### 请求类型
GET

#### 接口路径
`/dictionaries/types/tree`

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": [
    {
      "id": 1,
      "code": "system",
      "name": "系统字典",
      "isSystem": true,
      "children": [
        {
          "id": 10,
          "code": "user_status",
          "name": "用户状态",
          "itemCount": 4
        }
      ]
    }
  ]
}
```

#### 开发思路
1. 查询所有字典类型
2. 构建树形结构
3. 统计每个类型的字典项数量
4. 使用Redis缓存

---

### 7.2 获取字典项

#### 需求描述
根据字典类型获取所有字典项，支持树形字典。

#### 接口名称
获取字典项接口

#### 设计原因
- 前端下拉框等组件需要字典数据
- 支持动态配置
- 减少硬编码

#### 请求类型
GET

#### 接口路径
`/dictionaries/items`

#### 接口参数
```typescript
{
  typeCode: string;     // 字典类型代码
  tree?: boolean;       // 是否返回树形结构
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": [
    {
      "key": "active",
      "value": "active",
      "label": "正常",
      "labelEn": "Active",
      "color": "#52c41a",
      "sortOrder": 1,
      "extra": {}
    }
  ]
}
```

#### 开发思路
1. 根据typeCode查询字典类型
2. 查询该类型下的所有字典项
3. 如果是树形字典，构建树结构
4. 使用Redis缓存（字典变更少）

---

### 7.3 创建字典类型

#### 需求描述
创建新的字典类型。

#### 接口名称
创建字典类型接口

#### 设计原因
- 业务扩展需要新字典
- 灵活的配置管理
- 支持分类组织

#### 请求类型
POST

#### 接口路径
`/dictionaries/types`

#### 接口参数
```typescript
{
  code: string;         // 字典类型代码
  name: string;         // 字典类型名称
  pid?: number;         // 父类型ID
  description?: string; // 描述
  sortOrder?: number;   // 排序号
}
```

#### 开发思路
1. 权限检查（需要dictionary:create权限）
2. 验证代码唯一性
3. 创建字典类型
4. 清除字典缓存

---

### 7.4 批量更新字典项

#### 需求描述
支持批量更新字典项，保持顺序。

#### 接口名称
批量更新字典项接口

#### 设计原因
- 字典项通常需要批量维护
- 保持显示顺序的一致性
- 提高维护效率

#### 请求类型
PUT

#### 接口路径
`/dictionaries/types/{typeId}/items/batch`

#### 接口参数
```typescript
{
  items: Array<{
    id?: number;        // 有ID为更新，无ID为新增
    key: string;
    value: string;
    label: string;
    labelEn?: string;
    pid?: number;
    sortOrder: number;
    status?: string;
    color?: string;
    extra?: object;
  }>
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "批量更新成功",
  "data": {
    "created": 3,
    "updated": 5,
    "deleted": 2
  }
}
```

#### 开发思路
1. 验证字典类型存在
2. 检查是否为系统字典
3. 验证key在类型内唯一
4. 使用事务处理：
   - 标记删除不在列表中的项
   - 更新已存在的项
   - 创建新项
5. 清除字典缓存

---

### 7.5 导出字典数据

#### 需求描述
导出字典配置用于备份或迁移。

#### 接口名称
导出字典数据接口

#### 设计原因
- 配置备份需求
- 环境间迁移
- 批量导入导出

#### 请求类型
GET

#### 接口路径
`/dictionaries/export`

#### 接口参数
```typescript
{
  typeIds?: number[];   // 指定类型ID，不传则导出全部
  format?: string;      // 导出格式：json,excel
}
```

#### 响应格式
```
Content-Type: application/octet-stream
Content-Disposition: attachment; filename="dictionaries_20240101.json"
```

#### 开发思路
1. 查询指定的字典类型和项
2. 构建导出数据结构
3. 根据格式生成文件
4. 返回文件流

---

## 8. 标签管理模块 (Tag Management)

### 8.1 标签列表查询

#### 需求描述
查询标签列表，支持按类型和使用频率排序。

#### 接口名称
标签列表查询接口

#### 设计原因
- 便于标签的统一管理
- 支持热门标签展示
- 不同类型标签分开管理

#### 请求类型
GET

#### 接口路径
`/tags`

#### 接口参数
```typescript
{
  type?: string;        // 标签类型
  keyword?: string;     // 搜索关键词
  sortBy?: string;      // 排序：usageCount,createdAt
  page?: number;
  pageSize?: number;
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "items": [
      {
        "id": 1,
        "name": "VIP",
        "type": "user",
        "color": "#ff4d4f",
        "usageCount": 100,
        "description": "VIP用户"
      }
    ],
    "pagination": {
      "page": 1,
      "pageSize": 20,
      "total": 50
    }
  }
}
```

#### 开发思路
1. 构建查询条件
2. 执行分页查询
3. 根据sortBy排序
4. 返回标签列表

---

### 8.2 创建标签

#### 需求描述
创建新的标签。

#### 接口名称
创建标签接口

#### 设计原因
- 灵活的标签扩展
- 支持自定义标签
- 统一标签管理

#### 请求类型
POST

#### 接口路径
`/tags`

#### 接口参数
```typescript
{
  name: string;         // 标签名称
  type: string;         // 标签类型
  color?: string;       // 标签颜色
  description?: string; // 描述
}
```

#### 开发思路
1. 权限检查（需要tag:create权限）
2. 验证标签名称唯一性（同类型内）
3. 创建标签记录
4. 返回创建结果

---

### 8.3 标签使用统计

#### 需求描述
统计标签使用情况，生成报表。

#### 接口名称
标签使用统计接口

#### 设计原因
- 了解标签使用情况
- 优化标签体系
- 数据分析支持

#### 请求类型
GET

#### 接口路径
`/tags/statistics`

#### 接口参数
```typescript
{
  type?: string;        // 标签类型
  top?: number;         // 返回前N个
  startDate?: string;   // 统计开始时间
  endDate?: string;     // 统计结束时间
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "summary": {
      "totalTags": 50,
      "totalUsage": 1000,
      "avgUsage": 20
    },
    "topTags": [
      {
        "id": 1,
        "name": "VIP",
        "usageCount": 100,
        "percentage": 10
      }
    ],
    "trend": [
      {
        "date": "2024-01-01",
        "count": 20
      }
    ]
  }
}
```

#### 开发思路
1. 统计基础数据
2. 查询热门标签
3. 计算使用趋势
4. 整合返回结果

---

### 8.4 标签智能推荐

#### 需求描述
根据用户特征智能推荐标签。

#### 接口名称
标签推荐接口

#### 设计原因
- 提高标签使用的准确性
- 基于规则引擎自动打标
- 减少人工维护成本

#### 请求类型
POST

#### 接口路径
`/tags/recommend`

#### 接口参数
```typescript
{
  userId: number;       // 用户ID
  type: string;         // 推荐类型
  limit?: number;       // 推荐数量限制
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "recommendations": [
      {
        "tagId": 1,
        "tagName": "活跃用户",
        "confidence": 0.95,
        "reason": "最近30天登录20次"
      }
    ]
  }
}
```

#### 开发思路
1. 获取用户特征数据
2. 执行推荐规则：
   - 活跃度规则（登录次数、最后登录时间）
   - 贡献度规则（内容创作数量）
   - 消费规则（VIP等级）
3. 计算置信度
4. 返回推荐标签列表
5. 记录推荐日志

---

### 8.5 批量打标签

#### 需求描述
为多个用户批量添加或移除标签。

#### 接口名称
批量打标签接口

#### 设计原因
- 提高运营效率
- 支持批量操作
- 灵活的标签管理

#### 请求类型
POST

#### 接口路径
`/tags/batch-assign`

#### 接口参数
```typescript
{
  userIds: number[];    // 用户ID数组
  tagIds: number[];     // 标签ID数组
  action: string;       // 操作：add,remove
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "批量操作成功",
  "data": {
    "success": 50,
    "failed": 0,
    "errors": []
  }
}
```

#### 开发思路
1. 权限检查
2. 验证用户和标签存在性
3. 批量执行操作
4. 更新标签使用统计
5. 返回执行结果
```

```markdown
// ... existing code ...

## 9. 通用功能接口

### 9.1 图形验证码

#### 需求描述
生成图形验证码，用于注册、登录等场景。

#### 接口名称
获取图形验证码接口

#### 设计原因
- 防止机器人攻击
- 增强系统安全性
- 限制恶意请求

#### 请求类型
GET

#### 接口路径
`/common/captcha`

#### 接口参数
```typescript
{
  type?: string;        // 验证码类型：image,math
  width?: number;       // 图片宽度，默认120
  height?: number;      // 图片高度，默认40
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "captchaId": "xxxx-xxxx-xxxx",
    "captchaImage": "data:image/svg+xml;base64,..."
  }
}
```

#### 开发思路
1. 生成随机验证码文本
2. 生成SVG或图片
3. 存储到Redis（5分钟过期）
4. 返回Base64编码的图片

---

### 9.2 文件上传

#### 需求描述
通用文件上传接口，支持头像等文件上传。

#### 接口名称
文件上传接口

#### 设计原因
- 统一的文件上传入口
- 支持多种文件类型
- 安全的文件处理

#### 请求类型
POST

#### 接口路径
`/common/upload`

#### 请求格式
multipart/form-data

#### 接口参数
```typescript
{
  file: File;           // 文件
  type: string;         // 文件类型：avatar,document,image
  isPublic?: boolean;   // 是否公开访问，默认false
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "上传成功",
  "data": {
    "fileId": "file123456",
    "url": "https://oss.starzh.com/xxx.jpg",
    "size": 102400,
    "name": "avatar.jpg",
    "type": "image/jpeg"
  }
}
```

#### 开发思路
1. 验证文件类型和大小
2. 生成唯一文件名
3. 上传到OSS或本地存储
4. 记录文件信息到数据库
5. 返回文件访问URL

---

### 9.3 邮件发送

#### 需求描述
统一的邮件发送接口，用于系统通知。

#### 接口名称
邮件发送接口（内部接口）

#### 设计原因
- 统一邮件发送逻辑
- 支持模板化
- 便于监控和管理

#### 请求类型
POST

#### 接口路径
`/internal/email/send`

#### 接口参数
```typescript
{
  to: string[];         // 收件人邮箱数组
  template: string;     // 邮件模板ID
  params: object;       // 模板参数
  attachments?: Array<{ // 附件
    filename: string;
    content: string;
  }>;
}
```

#### 开发思路
1. 加载邮件模板
2. 渲染模板内容
3. 调用邮件服务发送
4. 记录发送日志
5. 处理发送失败（重试机制）

---

### 9.4 系统健康检查

#### 需求描述
提供系统健康状态检查接口。

#### 接口名称
健康检查接口

#### 设计原因
- 监控系统状态
- 负载均衡健康检查
- 快速发现问题

#### 请求类型
GET

#### 接口路径
`/health`

#### 响应格式
```json
{
  "code": 0,
  "message": "success",
  "data": {
    "status": "healthy",
    "version": "1.0.0",
    "uptime": 3600,
    "services": {
      "database": "ok",
      "redis": "ok",
      "elasticsearch": "ok"
    }
  }
}
```

#### 开发思路
1. 检查数据库连接
2. 检查Redis连接
3. 检查其他服务状态
4. 返回综合健康状态

---

### 9.5 数据导入导出

#### 需求描述
支持批量数据的导入导出功能。

#### 接口名称
数据导出接口

#### 设计原因
- 数据备份需求
- 批量数据处理
- 数据迁移支持

#### 请求类型
POST

#### 接口路径
`/common/export`

#### 接口参数
```typescript
{
  module: string;       // 模块：users,roles,organizations
  format: string;       // 格式：excel,csv,json
  filters?: object;     // 过滤条件
  fields?: string[];    // 导出字段
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "导出任务已创建",
  "data": {
    "taskId": "export-123456",
    "status": "processing"
  }
}
```

#### 开发思路
1. 创建导出任务
2. 异步处理数据查询和转换
3. 生成导出文件
4. 通过WebSocket或轮询通知完成
5. 提供下载链接

---

## 10. 安全性设计

### 10.1 认证机制
- **JWT Token认证**
  - AccessToken有效期2小时
  - RefreshToken有效期7天
  - Token黑名单机制
  - 支持多设备登录管理

### 10.2 权限控制
- **基于RBAC的权限模型**
  - 接口级别的权限控制
  - 数据级别的权限过滤
  - 动态权限加载
  - 权限缓存优化

### 10.3 安全措施
- **传输安全**
  - 所有接口强制HTTPS
  - 敏感数据加密传输
  - 防重放攻击（时间戳+nonce）

- **输入验证**
  - 参数类型和格式验证
  - SQL注入防护（参数化查询）
  - XSS防护（输入过滤和转义）
  - 文件上传安全检查

- **访问控制**
  - IP白名单（管理接口）
  - 请求频率限制
  - 并发连接限制
  - 异常行为检测

### 10.4 日志审计
- **操作日志**
  - 记录所有写操作
  - 包含用户、时间、IP、操作内容
  - 敏感操作实时告警

- **安全日志**
  - 登录失败记录
  - 权限拒绝记录
  - 异常请求记录

---

## 11. 性能优化

### 11.1 缓存策略

| 缓存类型 | 缓存内容 | 过期时间 | 更新策略 |
|---------|---------|---------|---------|
| 用户信息缓存 | 基本信息、角色、权限 | 5分钟 | 主动更新+过期刷新 |
| 角色权限缓存 | 角色树、权限快照 | 1小时 | 变更时删除 |
| 字典缓存 | 字典类型和项 | 24小时 | 变更时删除 |
| 验证码缓存 | 图形验证码 | 5分钟 | 使用后删除 |

### 11.2 查询优化
- **索引优化**
  - 基于查询模式设计索引
  - 定期分析慢查询日志
  - 避免全表扫描

- **查询优化**
  - 使用预编译语句
  - 避免N+1查询
  - 合理使用JOIN和子查询
  - 大数据量分页优化

### 11.3 并发控制
- **限流策略**
  - 接口级别限流（令牌桶算法）
  - 用户级别限流
  - IP级别限流

- **资源控制**
  - 数据库连接池管理
  - Redis连接池管理
  - 异步任务队列

### 11.4 异步处理
- **异步任务**
  - 邮件发送
  - 文件处理
  - 数据导入导出
  - 统计计算

---

## 12. 错误处理

### 12.1 错误码规范

| 错误码范围 | 说明 | 示例 |
|-----------|------|------|
| 0 | 成功 | 操作成功 |
| 400xx | 客户端错误 | 40001-参数错误 |
| 401xx | 认证错误 | 40101-未登录 |
| 403xx | 权限错误 | 40301-无权限 |
| 404xx | 资源不存在 | 40401-用户不存在 |
| 409xx | 资源冲突 | 40901-用户名已存在 |
| 423xx | 资源锁定 | 42301-账号被锁定 |
| 429xx | 请求过多 | 42901-请求频率超限 |
| 500xx | 服务器错误 | 50001-内部错误 |
| 503xx | 服务不可用 | 50301-服务维护中 |

### 12.2 错误响应格式
```json
{
  "code": 40001,
  "message": "参数验证失败：用户名长度必须在3-50个字符之间",
  "data": {
    "field": "username",
    "value": "ab",
    "rule": "minLength"
  },
  "timestamp": 1640995200000,
  "requestId": "req-xxxx-xxxx",
  "path": "/api/v1/users"
}
```

### 12.3 错误处理最佳实践
- **友好的错误提示**
  - 使用用户能理解的语言
  - 提供解决建议
  - 避免暴露技术细节

- **错误日志记录**
  - 记录完整的错误堆栈
  - 包含请求上下文
  - 分级记录（info/warn/error）

- **错误监控告警**
  - 错误率监控
  - 关键错误实时告警
  - 错误趋势分析

---

## 13. 接口版本管理

### 13.1 版本策略
- **URL版本化**
  - 格式：`/api/v{n}/...`
  - 主版本号变更表示不兼容更新
  - 向后兼容原则

### 13.2 版本迁移
- **废弃通知**
  - 提前3个月通知
  - 响应头添加废弃警告
  - 提供迁移文档

- **版本共存**
  - 新旧版本并行运行
  - 逐步迁移用户
  - 设置旧版本下线时间

---

## 14. 开发规范总结

### 14.1 接口设计原则
- **RESTful规范**
  - 使用标准HTTP方法
  - 资源导向的URL设计
  - 合理使用状态码

- **一致性原则**
  - 统一的命名规范
  - 统一的响应格式
  - 统一的错误处理

### 14.2 最佳实践
- **幂等性设计**
  - GET/PUT/DELETE操作幂等
  - POST操作防重复提交

- **分页设计**
  - 统一分页参数
  - 限制最大返回条数
  - 提供总数统计

- **数据安全**
  - 敏感数据脱敏
  - 防止信息泄露
  - 输入验证和过滤

### 14.3 文档规范
- **接口文档**
  - 使用Swagger自动生成
  - 包含请求和响应示例
  - 说明业务场景

- **变更记录**
  - 记录所有API变更
  - 说明变更原因
  - 提供升级指南

---

## 15. 附录

### 15.1 常用正则表达式
```javascript
// 用户名：3-50位字母数字下划线，字母开头
const USERNAME_REGEX = /^[a-zA-Z][a-zA-Z0-9_]{2,49}$/;

// 邮箱
const EMAIL_REGEX = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;

// 手机号（中国大陆）
const MOBILE_REGEX = /^1[3-9]\d{9}$/;

// 强密码：8-100位，包含大小写字母和数字
const PASSWORD_REGEX = /^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)[a-zA-Z\d@$!%*?&]{8,100}$/;
```

### 15.2 时间格式约定
- 统一使用ISO 8601格式
- 示例：`2024-01-01T12:00:00Z`
- 时区：统一使用UTC时间

### 15.3 分页参数约定
- `page`: 页码，从1开始
- `pageSize`: 每页条数，默认20，最大100
- `total`: 总记录数
- `totalPages`: 总页数

---

本接口设计文档为M2基础用户系统的完整API规范，后续开发应严格遵循本文档的设计要求。
```

## 总结

我已经成功为您创建了《M2 - 基础用户系统 - 详细接口设计》文档（`prd/M2-基础用户系统-接口设计.md`），该文档全面覆盖了M2阶段基础用户系统的所有API接口设计。

### 文档特点：

1. **完整性**：包含了15个主要章节，涵盖了基础用户系统的所有模块
2. **规范性**：严格遵循RESTful设计原则，统一的接口格式和错误处理
3. **详细度**：每个接口都包含完整的9个设计要素，并根据需要补充了额外信息
4. **实用性**：提供了具体的开发思路和实现指导

### 文档结构：

1. **认证模块** - 5个接口（注册、登录、刷新Token、激活、退出）
2. **用户管理模块** - 9个接口（查询、创建、更新、删除、密码管理等）
3. **角色管理模块** - 6个接口（树查询、CRUD、权限分配、用户查询）
4. **权限管理模块** - 6个接口（树查询、CRUD、权限检查）
5. **组织架构模块** - 5个接口（树查询、CRUD、人员管理）
6. **字典管理模块** - 5个接口（类型管理、字典项管理、导出）
7. **标签管理模块** - 5个接口（CRUD、统计、智能推荐）
8. **通用功能接口** - 5个接口（验证码、文件上传、邮件、健康检查、导出）
9. **安全性设计** - 认证、权限、安全措施、审计
10. **性能优化** - 缓存、查询、并发、异步
11. **错误处理** - 错误码规范、响应格式、最佳实践
12. **版本管理** - 版本策略、迁移方案
13. **开发规范** - 设计原则、最佳实践、文档规范
14. **附录** - 正则表达式、格式约定

### 关键设计亮点：

- ✅ **安全性**：JWT双Token机制、权限继承、防暴力破解、数据脱敏
- ✅ **性能**：多级缓存策略、查询优化、异步处理、并发控制
- ✅ **扩展性**：树形结构设计、灵活的权限模型、标签系统
- ✅ **用户体验**：统一响应格式、友好错误提示、批量操作支持

### 与数据库设计的对应：

接口设计完全基于之前的数据库设计文档，确保了：
- 所有数据表都有对应的CRUD接口
- 树形结构（角色、权限、组织、字典）都有专门的树查询接口
- 关联关系（用户-角色、角色-权限等）都有批量管理接口
- 特殊功能（如is_root用户）在接口中有相应的权限控制

文档共2688行，约70KB，为后续的开发实现提供了详尽的指导。您可以基于这份接口设计文档进行API开发了。

---

**User**

关于列表性的数据，如何排序，是否需要增加排序接口

---

**Cursor**

您提出了一个非常重要的问题！在列表性数据管理中，排序确实是一个关键功能。让我分析一下当前接口设计中的排序情况，并补充必要的排序接口。

根据您的问题，我分析了当前接口设计中的排序情况。确实存在一些需要补充的排序功能。让我为您详细说明：

## 当前排序功能现状

### 🎯 已有的排序功能
1. **查询时排序**：用户列表、标签列表等支持`sortBy`和`sortOrder`参数
2. **字段排序**：数据库设计中有`sortOrder`字段
3. **自动排序**：按创建时间、更新时间、使用频率等

### 🔧 缺失的排序功能
对于需要**手动调整显示顺序**的场景，我们确实需要增加专门的排序接口：

## 建议增加的排序接口

```markdown
---

## 4.7 角色排序接口

#### 需求描述
支持手动调整角色的显示顺序，保证同级角色按指定顺序展示。

#### 接口名称
角色排序接口

#### 设计原因
- 角色列表需要按重要性排序
- 下拉选择时按业务优先级展示
- 管理员需要控制显示顺序

#### 请求类型
PUT

#### 接口路径
`/roles/sort`

#### 接口参数
```typescript
{
  items: Array<{
    id: number;         // 角色ID
    sortOrder: number;  // 新的排序号
  }>
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "排序更新成功",
  "data": {
    "updated": 5
  }
}
```

#### 开发思路
1. 权限检查（需要role:sort权限）
2. 批量更新sortOrder字段
3. 确保同级别角色排序唯一性
4. 清除角色缓存
5. 返回更新结果

---

## 4.8 拖拽排序接口

#### 需求描述
支持前端拖拽方式调整角色顺序，更直观的操作方式。

#### 接口名称
拖拽排序接口

#### 设计原因
- 提供更好的用户体验
- 直观的排序操作
- 减少误操作

#### 请求类型
PUT

#### 接口路径
`/roles/{roleId}/move`

#### 接口参数
```typescript
{
  targetIndex: number;  // 目标位置索引（0开始）
  pid?: number;         // 父级ID，如果跨级移动
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "移动成功",
  "data": {
    "roleId": 10,
    "oldIndex": 2,
    "newIndex": 0,
    "affectedRoles": [8, 9, 10]
  }
}
```

#### 开发思路
1. 计算目标位置的sortOrder值
2. 更新被移动角色的sortOrder
3. 调整其他角色的sortOrder（避免冲突）
4. 如果跨级移动，同时更新pid
5. 清除相关缓存

---

## 5.7 权限排序接口

#### 需求描述
调整权限的显示顺序，特别是菜单权限的排序。

#### 接口名称
权限排序接口

#### 设计原因
- 菜单权限需要控制显示顺序
- 影响前端菜单渲染顺序
- 提升用户体验

#### 请求类型
PUT

#### 接口路径
`/permissions/sort`

#### 接口参数
```typescript
{
  items: Array<{
    id: number;
    sortOrder: number;
  }>
}
```

#### 开发思路
1. 权限检查（需要permission:sort权限）
2. 批量更新权限排序
3. 确保同级权限排序唯一
4. 清除权限缓存
5. 通知前端刷新菜单

---

## 6.6 组织架构排序接口

#### 需求描述
调整同级组织的显示顺序。

#### 接口名称
组织排序接口

#### 设计原因
- 组织架构显示需要符合实际层级
- 重要部门需要前置显示
- 便于组织管理

#### 请求类型
PUT

#### 接口路径
`/organizations/{pid}/sort`

#### 接口参数
```typescript
{
  items: Array<{
    id: number;
    sortOrder: number;
  }>
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "组织排序更新成功",
  "data": {
    "parentId": 1,
    "updated": 3
  }
}
```

#### 开发思路
1. 验证所有组织都属于同一父级
2. 批量更新sortOrder
3. 清除组织架构缓存
4. 返回更新结果

---

## 7.6 字典项排序接口

#### 需求描述
调整字典项的显示顺序，影响下拉框等组件的选项顺序。

#### 接口名称
字典项排序接口

#### 设计原因
- 下拉框选项需要按业务逻辑排序
- 常用选项前置显示
- 提升用户操作效率

#### 请求类型
PUT

#### 接口路径
`/dictionaries/types/{typeId}/items/sort`

#### 接口参数
```typescript
{
  items: Array<{
    id: number;
    sortOrder: number;
  }>
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "字典项排序更新成功",
  "data": {
    "typeId": 1,
    "updated": 4
  }
}
```

#### 开发思路
1. 验证所有字典项都属于指定类型
2. 批量更新sortOrder
3. 清除字典缓存
4. 返回更新结果

---

## 8.6 标签排序接口

#### 需求描述
调整标签的显示顺序，支持热门标签前置。

#### 接口名称
标签排序接口

#### 设计原因
- 热门标签需要前置显示
- 按业务重要性排序
- 提升标签选择效率

#### 请求类型
PUT

#### 接口路径
`/tags/sort`

#### 接口参数
```typescript
{
  type?: string;        // 标签类型，为空则排序全部
  items: Array<{
    id: number;
    sortOrder: number;
  }>
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "标签排序更新成功",
  "data": {
    "type": "user",
    "updated": 6
  }
}
```

#### 开发思路
1. 权限检查（需要tag:sort权限）
2. 验证标签类型一致性
3. 批量更新sortOrder
4. 更新标签缓存
5. 返回更新结果

---

## 9.6 通用排序接口

#### 需求描述
提供通用的排序接口，支持多种数据类型的排序。

#### 接口名称
通用排序接口

#### 设计原因
- 统一的排序逻辑
- 减少代码重复
- 便于维护和扩展

#### 请求类型
PUT

#### 接口路径
`/common/sort`

#### 接口参数
```typescript
{
  table: string;        // 表名：roles,permissions,organizations,tags
  scopeField?: string;  // 范围字段：pid,typeId等
  scopeValue?: any;     // 范围值
  items: Array<{
    id: number;
    sortOrder: number;
  }>
}
```

#### 响应格式
```json
{
  "code": 0,
  "message": "排序更新成功",
  "data": {
    "table": "roles",
    "scope": "pid=1",
    "updated": 5
  }
}
```

#### 开发思路
1. 验证表名和字段的安全性
2. 权限检查（根据表名动态判断）
3. 构建更新SQL
4. 批量更新排序字段
5. 清除相关缓存
6. 返回更新结果

---
```

很好的问题！我已经为您补充了完整的排序接口设计。让我总结一下排序功能的完整方案：

## 📊 排序功能完整设计

### 1️⃣ 两种排序模式

| 排序类型 | 应用场景 | 实现方式 | 示例 |
|---------|---------|---------|------|
| **查询排序** | 列表展示时的动态排序 | `sortBy` + `sortOrder` 参数 | 按创建时间、使用频率排序 |
| **持久排序** | 管理员手动设置的固定顺序 | `sortOrder` 字段 + 排序接口 | 菜单顺序、角色优先级 |

### 2️⃣ 新增的排序接口

#### 🎯 专用排序接口
- **`PUT /roles/sort`** - 角色排序
- **`PUT /permissions/sort`** - 权限排序（菜单顺序）
- **`PUT /organizations/{pid}/sort`** - 组织架构排序
- **`PUT /dictionaries/types/{typeId}/items/sort`** - 字典项排序
- **`PUT /tags/sort`** - 标签排序

#### 🔄 拖拽排序接口
- **`PUT /roles/{roleId}/move`** - 支持拖拽调整位置

#### ⚙️ 通用排序接口
- **`PUT /common/sort`** - 统一排序逻辑，减少代码重复

### 3️⃣ 排序功能的核心价值

| 功能模块 | 排序意义 | 业务价值 |
|---------|---------|---------|
| **角色排序** | 按重要性展示 | 重要角色前置选择 |
| **权限排序** | 菜单显示顺序 | 符合用户操作习惯 |
| **组织排序** | 部门重要性 | 重要部门优先展示 |
| **字典排序** | 下拉选项顺序 | 常用选项前置 |
| **标签排序** | 热门标签前置 | 提升标签选择效率 |

### 4️⃣ 排序接口设计亮点

#### ✨ 批量操作
```typescript
// 支持批量更新多个项的排序
{
  items: Array<{
    id: number;
    sortOrder: number;
  }>
}
```

#### 🎯 拖拽支持
```typescript
// 支持拖拽操作，自动计算新位置
{
  targetIndex: number;  // 目标位置
  pid?: number;         // 支持跨级移动
}
```

#### 🔄 缓存管理
```javascript
// 排序更新后自动清除相关缓存
1. 清除角色缓存
2. 清除权限缓存  
3. 通知前端刷新
```

### 5️⃣ 排序的最佳实践

#### 📋 数据库设计
```sql
-- 每个需要排序的表都有sortOrder字段
ALTER TABLE sys_roles ADD COLUMN sort_order INT DEFAULT 0;
ALTER TABLE sys_permissions ADD COLUMN sort_order INT DEFAULT 0;

-- 创建排序索引
CREATE INDEX idx_roles_sort ON sys_roles(pid, sort_order);
```

#### 🔧 前端实现建议
```typescript
// 1. 拖拽排序组件
const handleDragEnd = (result) => {
  const { source, destination } = result;
  if (!destination) return;
  
  // 调用排序接口
  updateSort({
    targetIndex: destination.index,
    pid: currentParentId
  });
};

// 2. 批量排序
const batchUpdateSort = (items) => {
  const sortData = items.map((item, index) => ({
    id: item.id,
    sortOrder: (index + 1) * 10  // 留间隔便于插入
  }));
  
  api.put('/roles/sort', { items: sortData });
};
```

### 6️⃣ 权限控制
```typescript
// 每个排序接口都有对应的权限
role:sort       // 角色排序权限
permission:sort // 权限排序权限
organization:sort // 组织排序权限
dictionary:sort // 字典排序权限
tag:sort       // 标签排序权限
```

## 🚀 使用场景示例

### 场景1：菜单管理
管理员需要调整系统菜单的显示顺序：
```typescript
PUT /permissions/sort
{
  "items": [
    { "id": 1, "sortOrder": 10 },  // 系统管理
    { "id": 2, "sortOrder": 20 },  // 用户管理  
    { "id": 3, "sortOrder": 30 }   // 角色管理
  ]
}
```

### 场景2：下拉选项优化
优化用户状态下拉框的选项顺序：
```typescript
PUT /dictionaries/types/1/items/sort
{
  "items": [
    { "id": 1, "sortOrder": 10 },  // 正常（最常用）
    { "id": 2, "sortOrder": 20 },  // 禁用
    { "id": 3, "sortOrder": 30 }   // 锁定
  ]
}
```

### 场景3：拖拽操作
用户在前端拖拽角色到新位置：
```typescript
PUT /roles/10/move
{
  "targetIndex": 0,  // 移动到第一位
  "pid": 1          // 父角色ID
}
```

这样的设计既满足了灵活的排序需求，又保持了API的一致性和易用性。您觉得这个排序方案如何？还有其他需要补充的排序场景吗？

```typescript
// 支持批量更新多个项的排序
{
  items: Array<{
    id: number;
    sortOrder: number;
  }>
}
```

```typescript
// 支持拖拽操作，自动计算新位置
{
  targetIndex: number;  // 目标位置
  pid?: number;         // 支持跨级移动
}
```

```javascript
// 排序更新后自动清除相关缓存
1. 清除角色缓存
2. 清除权限缓存  
3. 通知前端刷新
```

```sql
-- 每个需要排序的表都有sortOrder字段
ALTER TABLE sys_roles ADD COLUMN sort_order INT DEFAULT 0;
ALTER TABLE sys_permissions ADD COLUMN sort_order INT DEFAULT 0;

-- 创建排序索引
CREATE INDEX idx_roles_sort ON sys_roles(pid, sort_order);
```

```typescript
// 1. 拖拽排序组件
const handleDragEnd = (result) => {
  const { source, destination } = result;
  if (!destination) return;
  
  // 调用排序接口
  updateSort({
    targetIndex: destination.index,
    pid: currentParentId
  });
};

// 2. 批量排序
const batchUpdateSort = (items) => {
  const sortData = items.map((item, index) => ({
    id: item.id,
    sortOrder: (index + 1) * 10  // 留间隔便于插入
  }));
  
  api.put('/roles/sort', { items: sortData });
};
```

```typescript
// 每个排序接口都有对应的权限
role:sort       // 角色排序权限
permission:sort // 权限排序权限
organization:sort // 组织排序权限
dictionary:sort // 字典排序权限
tag:sort       // 标签排序权限
```

```typescript
PUT /permissions/sort
{
  "items": [
    { "id": 1, "sortOrder": 10 },  // 系统管理
    { "id": 2, "sortOrder": 20 },  // 用户管理  
    { "id": 3, "sortOrder": 30 }   // 角色管理
  ]
}
```

```typescript
PUT /dictionaries/types/1/items/sort
{
  "items": [
    { "id": 1, "sortOrder": 10 },  // 正常（最常用）
    { "id": 2, "sortOrder": 20 },  // 禁用
    { "id": 3, "sortOrder": 30 }   // 锁定
  ]
}
```

```typescript
PUT /roles/10/move
{
  "targetIndex": 0,  // 移动到第一位
  "pid": 1          // 父角色ID
}
```

---

**User**

帮我生成git提交的commit文本

---

**Cursor**

```plaintext
<type>(<scope>): <subject>
```

根据您的修改内容，我来为您生成符合项目规范的Git提交信息：

基于您对 `M2-基础用户系统-接口设计.md` 文件的修改，我为您生成以下Git提交信息：

## 🎯 推荐的Commit信息：

### 主要提交信息（简洁版）：
```bash
git commit -m "feat(api): 新增排序接口设计并优化响应格式" -m "- 新增6个排序相关接口：角色、权限、组织、字典、标签排序" -m "- 支持拖拽排序和批量排序操作" -m "- 简化统一响应格式，移除timestamp和requestId字段" -m "- 完善M2基础用户系统接口设计文档"
```

### 详细版本（如果需要更详细的描述）：
```bash
git commit -m "feat(api): 新增完整的排序接口设计体系

✨ 新增功能：
- 角色排序接口 (PUT /roles/sort)
- 拖拽排序接口 (PUT /roles/{roleId}/move)  
- 权限排序接口 (PUT /permissions/sort)
- 组织架构排序接口 (PUT /organizations/{pid}/sort)
- 字典项排序接口 (PUT /dictionaries/types/{typeId}/items/sort)
- 标签排序接口 (PUT /tags/sort)
- 通用排序接口 (PUT /common/sort)

🔧 优化改进：
- 简化统一响应格式，移除timestamp和requestId字段
- 完善排序权限控制设计
- 支持批量排序和拖拽操作
- 统一排序逻辑，减少代码重复

📚 文档更新：
- 完善M2基础用户系统接口设计文档
- 新增排序接口的详细设计说明
- 补充排序功能的业务场景和实现思路"
```

### 超简洁版本：
```bash
git commit -m "feat(api): 新增排序接口设计和响应格式优化"
```

## 📋 提交内容摘要：

| 变更类型 | 变更内容 | 文件数量 |
|---------|---------|---------|
| ✨ 新增功能 | 7个排序相关接口设计 | 1 |
| 🔧 格式优化 | 简化响应格式结构 | 1 |
| 📚 文档完善 | 接口设计文档更新 | 1 |

我建议使用**主要提交信息（简洁版）**，因为它既包含了关键信息，又保持了简洁性，符合项目的Git提交规范。您觉得哪个版本更合适？

```shellscript
git commit -m "feat(api): 新增排序接口设计并优化响应格式" -m "- 新增6个排序相关接口：角色、权限、组织、字典、标签排序" -m "- 支持拖拽排序和批量排序操作" -m "- 简化统一响应格式，移除timestamp和requestId字段" -m "- 完善M2基础用户系统接口设计文档"
```

```shellscript
git commit -m "feat(api): 新增完整的排序接口设计体系

✨ 新增功能：
- 角色排序接口 (PUT /roles/sort)
- 拖拽排序接口 (PUT /roles/{roleId}/move)  
- 权限排序接口 (PUT /permissions/sort)
- 组织架构排序接口 (PUT /organizations/{pid}/sort)
- 字典项排序接口 (PUT /dictionaries/types/{typeId}/items/sort)
- 标签排序接口 (PUT /tags/sort)
- 通用排序接口 (PUT /common/sort)

🔧 优化改进：
- 简化统一响应格式，移除timestamp和requestId字段
- 完善排序权限控制设计
- 支持批量排序和拖拽操作
- 统一排序逻辑，减少代码重复

📚 文档更新：
- 完善M2基础用户系统接口设计文档
- 新增排序接口的详细设计说明
- 补充排序功能的业务场景和实现思路"
```

```shellscript
git commit -m "feat(api): 新增排序接口设计和响应格式优化"
```

---

**User**

这是未提交的文件，对这些内容生成详细的commit内容，我自己提交

---

**Cursor**

根据您的Git状态，我为您生成详细的commit信息。这是一个包含完整PRD文档体系的重要提交：

## 🎯 推荐的详细Commit信息：

```bash
git commit -m "feat(docs): 完成星撰平台M2基础用户系统完整设计文档体系

✨ 新增功能设计文档：
- M2基础用户系统数据库设计（12个核心表，RBAC权限模型）
- M2基础用户系统接口设计（41个API接口，含排序功能）
- 完整的项目需求文档和开发计划

📚 核心文档结构：
- 数据库设计：支持树形结构、软删除、审计日志的完整用户权限体系
- 接口设计：包含认证、用户管理、角色权限、组织架构、字典标签等9大模块
- 排序功能：新增7个排序接口，支持拖拽和批量操作
- 项目规划：从MVP到完整生态的4阶段开发计划

🔧 技术栈确定：
- 后端：Elysia + Bun.js + MySQL + Redis + Elasticsearch
- 前端：Vue.js/React + TypeScript
- 部署：Docker + Docker Compose
- 测试：Vitest + 完整测试规范

📋 设计亮点：
- 无外键约束设计，应用层维护数据完整性
- 树形结构支持（path、level字段优化查询）
- 完整的权限继承机制和权限快照
- 支持root超级管理员和多级角色体系
- 标签系统和智能推荐功能
- 统一的响应格式和错误码规范

🎯 覆盖功能：
- 用户认证与管理（注册、登录、权限控制）
- RBAC角色权限体系（树形角色、权限继承）
- 组织架构管理（多级组织、人员分配）
- 数据字典与标签系统
- 完整的排序和数据导入导出功能

📈 文档规模：
- 数据库设计：38KB，922行
- 接口设计：55KB，3024行
- 总计：约100KB的详细技术文档

🔄 配套更新：
- 更新Elysia后端开发规范
- 完善健康检查控制器
- 统一项目代码规范和注释规范"
```

## 📋 提交内容详细分析：

### 📄 新增文档列表：
| 文档名称 | 类型 | 内容重点 | 文件大小 |
|---------|------|---------|---------|
| M2-基础用户系统-数据库设计.md | 数据库设计 | 12个核心表+ER图+索引优化 | 38KB |
| M2-基础用户系统-接口设计.md | API设计 | 41个接口+9大模块+排序功能 | 55KB |
| 星撰-开发计划.md | 项目规划 | 4阶段开发计划+功能模块 | 7KB |
| 星撰-概要设计.md | 架构设计 | 技术栈+系统架构+开发流程 | 11KB |
| 星撰-工程设计.md | 工程设计 | 技术指标+可行性+前沿技术 | 13KB |
| personal-website-comprehensive-prd.md | 产品需求 | 完整功能需求+用户故事 | 16KB |
| main.md | 功能概述 | 核心功能列表 | 2KB |

### 🔧 修改文件：
| 文件名称 | 修改内容 | 目的 |
|---------|---------|------|
| .cursor/rules/elysia-backend-rules.mdc | 更新开发规范 | 完善项目规范 |
| src/controllers/health.controller.ts | 优化健康检查 | 改进监控功能 |

### ⚠️ 未跟踪文件：
- `bun.lock` - 依赖锁定文件，建议添加到版本控制

## 🚀 简化版本（如果需要更简洁）：

```bash
git commit -m "feat(docs): 完成M2基础用户系统完整设计文档

- 新增数据库设计文档（12个核心表，RBAC权限模型）
- 新增接口设计文档（41个API，9大功能模块）
- 新增项目规划和架构设计文档
- 完善开发规范和代码标准
- 总计约100KB的详细技术文档"
```

## 📝 提交建议：

1. **建议添加bun.lock文件**：
```bash
git add bun.lock
```

2. **这是一个里程碑式的提交**，建议使用详细版本的commit信息，因为：
   - 包含了完整的系统设计
   - 是项目的重要文档基础
   - 后续开发将基于这些设计文档

您觉得这个commit信息如何？需要我调整哪些部分吗？

```shellscript
git commit -m "feat(docs): 完成星撰平台M2基础用户系统完整设计文档体系

✨ 新增功能设计文档：
- M2基础用户系统数据库设计（12个核心表，RBAC权限模型）
- M2基础用户系统接口设计（41个API接口，含排序功能）
- 完整的项目需求文档和开发计划

📚 核心文档结构：
- 数据库设计：支持树形结构、软删除、审计日志的完整用户权限体系
- 接口设计：包含认证、用户管理、角色权限、组织架构、字典标签等9大模块
- 排序功能：新增7个排序接口，支持拖拽和批量操作
- 项目规划：从MVP到完整生态的4阶段开发计划

🔧 技术栈确定：
- 后端：Elysia + Bun.js + MySQL + Redis + Elasticsearch
- 前端：Vue.js/React + TypeScript
- 部署：Docker + Docker Compose
- 测试：Vitest + 完整测试规范

📋 设计亮点：
- 无外键约束设计，应用层维护数据完整性
- 树形结构支持（path、level字段优化查询）
- 完整的权限继承机制和权限快照
- 支持root超级管理员和多级角色体系
- 标签系统和智能推荐功能
- 统一的响应格式和错误码规范

🎯 覆盖功能：
- 用户认证与管理（注册、登录、权限控制）
- RBAC角色权限体系（树形角色、权限继承）
- 组织架构管理（多级组织、人员分配）
- 数据字典与标签系统
- 完整的排序和数据导入导出功能

📈 文档规模：
- 数据库设计：38KB，922行
- 接口设计：55KB，3024行
- 总计：约100KB的详细技术文档

🔄 配套更新：
- 更新Elysia后端开发规范
- 完善健康检查控制器
- 统一项目代码规范和注释规范"
```

```shellscript
git commit -m "feat(docs): 完成M2基础用户系统完整设计文档

- 新增数据库设计文档（12个核心表，RBAC权限模型）
- 新增接口设计文档（41个API，9大功能模块）
- 新增项目规划和架构设计文档
- 完善开发规范和代码标准
- 总计约100KB的详细技术文档"
```

```shellscript
git add bun.lock
```

